# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS                               
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#
# Description: IBGD building environment
#


ARCH=`uname -m`
K_VER=`uname -r`
RPMK_VER=`uname -r | tr -s '-' '_'`
IB_PORTS_NUM=2

NULL=/dev/null
curr_dir=$PWD

RM=/bin/rm
CP=/bin/cp
MV=/bin/mv
MKDIR=/bin/mkdir
RPM=/bin/rpm
IFCONFIG=/sbin/ifconfig
CHMOD=/bin/chmod
LSMOD=/sbin/lsmod
DF=/bin/df
REBOOT="/sbin/shutdown -r 0"
IFS=' '
SUPPORTED=0
NEED_REBOOT=0
EXECUTING=0

# Disk space required for building IBGD RPMs (600 MB)
BUILD_SPACE_REQ=614400

# Disk space required for installing IBGD RPMs (200 MB)
RUN_SPACE_REQ=204800

# Default vendor is "ts" (second - mtl)
VENDOR="ts"
build_arch=`$RPM --showrc | grep -w "build arch" | cut -d : -f 2 | tr -d [:space:]`

# Versions definitions:

OPENIB_NAME="openib"
OPENIB_VER=1.7.0

OPENSM_NAME="opensm"
OPENSM_VER=1.7.0

MST_NAME="mst"
MST_VER=4.0.3

IBADM_NAME="ibadm"
IBADM_VER=1.7.0

MPI_NCSA_NAME="MPI_NCSA"
MPI_NCSA_VER=""
MPI_NCSA_MPICH_NAME="mpich_mlx-ch_vmi"
MPI_NCSA_MPICH_VER=2.0.1
MPI_NCSA_VMI_NAME="vmi_mlx"
MPI_NCSA_VMI_VER=2.0.1

MPI_OSU_NAME="MPI_OSU"
MPI_OSU_VER=""
MPI_OSU_MPICH_NAME="mpich_mlx"
MPI_OSU_MPICH_VER=0.9.4

IBFW_NAME="ibgd1.7.0.fwrel.tgz"                 

# Sources path definitions
PKG_SOURCE_DIR=${PWD}

OPENIB_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${OPENIB_NAME}-${OPENIB_VER}.tgz
OPENSM_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${OPENSM_NAME}-${OPENSM_VER}.tgz
MST_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${MST_NAME}-${ARCH}-${MST_VER}.tgz
IBADM_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${IBADM_NAME}-${IBADM_VER}.tgz
NCSA_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${MPI_NCSA_NAME}.tgz
OSU_SOURCE=${PKG_SOURCE_DIR}/SOURCES/${MPI_OSU_NAME}.tgz
SCRIPTS_SOURCE=${PKG_SOURCE_DIR}
DOCS_SOURCE=${PKG_SOURCE_DIR}/docs
#FW_SOURCE_DIR=${PKG_SOURCE_DIR}/SOURCES/FW

PROPEL=${PKG_SOURCE_DIR}/SOURCES/propel.sh

IBFW=${PKG_SOURCE_DIR}/SOURCES/$IBFW_NAME

RPMS=${PKG_SOURCE_DIR}/RPMS

if [ ! -d ${RPMS} ]; then
	$MKDIR -p ${RPMS} || exit 1
fi

# Check configuration file
[ -z "$CONFIG" ] && CONFIG=${PKG_SOURCE_DIR}/ibgd.conf

SET_CONFIG_NET=0
if [ -z "$CONFIG_NET" ]; then
 	CONFIG_NET=${PKG_SOURCE_DIR}/ibgd_net.conf
   touch $CONFIG_NET
   cat $NULL > ${CONFIG_NET}
	SET_CONFIG_NET=1
else
   if [ -s "$CONFIG_NET" ]; then
		. $CONFIG_NET
		SET_CONFIG_NET=0
	else
		SET_CONFIG_NET=1
	fi
fi

if [ $INTERACTIVE -eq 0 ]; then
	
   if [ -s "$CONFIG" ]; then
   	. $CONFIG 
   else	
   	echo "$CONFIG file does not exist or empty"
      exit 1
   fi
   	
   TT_COLOR=no
else
   touch $CONFIG || exit 1
   TT_COLOR=yes
fi

# Build Environment definition
BUILD_ROOT_DFT=${BUILD_ROOT:-/var/tmp/IBGD}
BUILD_ROOT=${BUILD_ROOT_DFT}
BUILD_TMP=/tmp

# Destination path definitions

STACK_PREFIX=${STACK_PREFIX:-/usr/local/ibgd}

OPENIB_DEST=${STACK_PREFIX}/driver/infinihost
OPENSM_DEST=${STACK_PREFIX}/apps/osm
MST_DEST=/usr/mst
IBADM_DEST=${STACK_PREFIX}/apps/ibadm
NCSA_DEST=${STACK_PREFIX}/mpi/ncsa
OSU_DEST=${STACK_PREFIX}/mpi/osu
SCRIPTS_DEST=${STACK_PREFIX}/scripts
FW_DEST=${STACK_PREFIX}

# Installation Backup directory
BACKUP=${STACK_PREFIX}/backup
BACKUPTMP=${BACKUP}/tmp
CURR=${BACKUP}/current
PREV=${BACKUP}/previous

REQUIRED_PACKAGES="openib:Infiniband HCA Driver and ULPs (IPoIB, SDP, SRP Host, uDAPL and kDAPL); opensm:Infiniband Subnet Manager; mst:Mellanox Tools; ibadm:Infiniband Administration Package;"
OPTIONAL_PACKAGES="mpi_osu:OSU MPI; mpi_ncsa:NCSA MPI;"

# Requirements definitions per package

openib_RUN_REQ="glib glibc readline termcap ncurses"
openib_BUILD_REQ="gcc glib glib-devel glibc glibc-devel termcap readline readline-devel ncurses ncurses-devel"
    
opensm_RUN_REQ=""
opensm_BUILD_REQ="glib glib-devel glibc glibc-devel readline readline-devel"

mst_RUN_REQ=""
mst_BUILD_REQ=""

ibadm_RUN_REQ="expat"
ibadm_BUILD_REQ="automake autoconf libtool expat zlib-devel"

mpi_ncsa_RUN_REQ="curl"
mpi_ncsa_BUILD_REQ="curl curl-devel libtool autoconf_2.52 automake_1.5"    

mpi_osu_RUN_REQ=""
mpi_osu_BUILD_REQ=""    

LOG=/tmp/IBGD.$$.log

# COLOR SETTINGS
SETCOLOR_SUCCESS="echo -en \\033[1;34m"
SETCOLOR_FAILURE="echo -en \\033[1;31m"
SETCOLOR_WARNING="echo -en \\033[1;35m"
SETCOLOR_NORMAL="echo -en \\033[0;39m"


err_echo()
{
IFS=' '
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_FAILURE
   echo -n "ERROR: $@" | tee -a $LOG
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_NORMAL
   echo
   return 0
}

warn_echo()
{
IFS=' '
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_WARNING
   echo -n "WARNING: $@" | tee -a $LOG
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_NORMAL
   echo
   return 0
}

pass_echo()
{
IFS=' '
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_SUCCESS
   echo -n "$@" | tee -a $LOG
   [ "$TT_COLOR" = "yes" ] && $SETCOLOR_NORMAL
   echo
   return 0
}
                    
                    
open_log()
{
 rm -f $LOG    
 touch $LOG
}

close_log()
{
 echo "`basename $0` finished: `date`" >> $LOG    
}

getch()
{
local ans
    echo -n "Press Enter to continue..."
    read ans
return 0
}


cleanup()
{
IFS=' '
local prog=`basename $0`
local ACTION
local ans

if [ $INTERACTIVE -eq 1 ]; then
   # IF in the install mode run uninstall
   if [ "$prog" == "install.sh" ]; then
      echo
      read -p  "Do you want to remove already installed IBGD packages?[Y/n]" ans
      if ! [[ "$ans" == "" || "$ans" == "y" || "$ans" == "Y" || "$ans" == "yes" ]]; then
         return 0
      fi   
      ACTION="uninstall"
   else
      # IF in the build mode delete BUILD_ROOT
      echo
      if [ -d "$BUILD_ROOT" ]; then
         read -p  "Do you want to remove temporary build directory $BUILD_ROOT [Y/n]?" ans
         if ! [[ "$ans" == "" || "$ans" == "y" || "$ans" == "Y" || "$ans" == "yes" ]]; then
            return 0
         fi   
      fi
      ACTION="delete"
   fi
else # Non interactive mode
   if [ "$prog" == "install.sh" ]; then
      ACTION="uninstall"
   else
      ACTION="leave"
   fi
fi

      case "$ACTION" in
            "uninstall")
               rmInstalled
            ;;
            "delete")
               [ -d "$BUILD_ROOT" ] && $RM -rf $BUILD_ROOT
            ;;
            *)
            ;;
      esac

   if [ $INTERACTIVE -eq 1 ]; then
      getch
   fi

}

# Returns "0" if $1 is integer and "1" otherwise
is_integer() 
{
IFS=' '
   printf "%s\n" $1 |grep -E "^[+-]?[0-9]+$" > $NULL
   return $?
}

kill_propel()
{
   [ -z $PR_PID ] && return 0
   if ! is_integer $PR_PID; then
      return 0
   fi
   if ! ( ps -p $PR_PID > $NULL 2>&1 ); then
      return 0
   fi

   kill -15 $PR_PID  > $NULL 2>&1
   sleep 1
}

trap_handler()
{
IFS=' '
local ans

if [ $EXECUTING -eq 0 ]; then
    echo
    read -p "Do you want to Cancel Installation?[y/N]:" ans
    if [ "$ans" == "y" ]; then
       kill_propel
       err_echo "Installation aborted by user"
       cleanup
       exit 1
    else
       return 0
    fi
else
    kill_propel
    err_echo "Installation aborted by user"
    cleanup
    exit 1    
fi
}

trap 'trap_handler' 2 9 15

# Execute command $@ and check exit status
ex()
{
EXECUTING=1
IFS=' '

   $PROPEL &
   PR_PID=$!

   echo Running $@
   eval "$@" >> $LOG 2>&1
   if [ $? -ne 0 ]; then
        echo
        err_echo Failed executing \"$@\"
        echo
        cd ${curr_dir}
        echo See log file: $LOG
        echo

        kill_propel

        if [ $INTERACTIVE -eq 1 ]; then
           getch
        fi
        cleanup
        exit 5
   fi

   kill_propel

EXECUTING=0   
}

# Execute command $@ in silent mode and check exit status
ex_silent()
{
EXECUTING=1
IFS=' '

#   echo Running $@
   eval "$@" >> $LOG 2>&1
   if [ $? -ne 0 ]; then
        echo
        err_echo Failed executing \"$@\"
        echo
        cd ${curr_dir}
        echo See log file: $LOG
        echo

        if [ $INTERACTIVE -eq 1 ]; then
           getch
        fi
        cleanup
        exit 5
   fi

EXECUTING=0   
}


check_user()
{
IFS=' '
   local user;
   user=`/usr/bin/id -u`
   if [ $user -ne 0 ]; then
        err_echo "You must be root to run this install program"
        exit 1
   fi
}
                            
get_ans()
{
IFS=' '
read ans
case $ans in
    Y|YES|y|yes)
        return 0
    ;;    
    *)
        return 1    
     ;;
esac        
}

show_menu()
{
IFS=' '

    clear
     case "$1" in
                 "main_menu")
cat << EOF_INST

         InfiniBand Gold Distribution (IBGD) Software Installation Menu

          1) View IBGD Installation Guide
          2) Install IBGD Software 
          3) Show Installed Software
          4) Configure IPoIB Network Interface, IBADM Server, and OpenSM Server
          5) Uninstall IBGD Software
          6) Build IBGD Software RPMs

          Q) Exit

EOF_INST
          
	echo -n   "Select Option [1-6]:"
                         ;;
                 "build_menu")
cat << EOF_BUILD

         InfiniBand Software Build Menu

          1) View README (read "Building IB SW RPM packages")
          2) Build InfiniBand Software RPMs

          Q) Exit

EOF_BUILD

	echo -n   "Select Option [1-2]:"

                 ;;
                 *)
                     return 1
                 ;;
     esac
    return 0
}

# Show README file
view_readme()
{
IFS=' '

local prog=`basename $0`

if [ "$prog" == "install.sh" ]; then
	less $PKG_SOURCE_DIR/docs/IBGD_Installation_Guide.txt
else
	less $PKG_SOURCE_DIR/README.txt
fi

return 0
}

# Check disk space requirments $1 - required size $2 - directory to check
check_space_req()
{
IFS=' '

   local space_req=$1
   local dir=$2
      shift 2

   while [ ! -d $dir ]
   do
      dir=${dir%*/*}
   done

   local avail_space=`$DF $dir | tail -1 | awk '{print$4}' | tr -d [:space:]`

   if ! is_integer $avail_space; then
      # Wrong avail_space found
      return 0
   fi

   if [ $avail_space -lt $space_req ]; then
        echo
        err_echo "Not enough disk space in the ${dir} directory. Required ${space_req}KB"
        echo
	if [ $INTERACTIVE -eq 1 ]; then
		getch
	fi
        exit 1
   fi

return 0
}

# Compare package versions $1 and $2. Return 0 if $1=$2, 1 if $1 > $2, 2 - if $1 < $2
compare()
{
IFS=' '
local ver1=`echo $1 | tr -d [:alpha:]`
local ver2=`echo $2 | tr -d [:alpha:]`
local dots1=0
local dots2=0
local dots=0
local diff=0

if [ "$ver1" == "$ver2" ]; then
    return 0
fi

[ "$ver1" == "" ] && ver1=0
[ "$ver2" == "" ] && ver2=0

dots1=`echo $ver1 | tr -d [:digit:] | tr -d [:space:] | wc -c | tr -d [:space:]`
dots2=`echo $ver2 | tr -d [:digit:] | tr -d [:space:] | wc -c | tr -d [:space:]`

if [ $dots1 -gt $dots2 ]; then
    dots=$dots2
    diff=1
elif [ $dots1 -lt $dots2 ]; then
    dots=$dots1
    diff=2
else
    dots=$dots1
    diff=0    
fi

let dots++
for (( i=1 ; i <= $dots ; i++ ))
do
    [ `echo $ver1 | cut -d . -f $i | tr -d [:space:]` -gt `echo $ver2 | cut -d . -f $i | tr -d [:space:]` ] && return 1
    [ `echo $ver1 | cut -d . -f $i | tr -d [:space:]` -lt `echo $ver2 | cut -d . -f $i | tr -d [:space:]` ] && return 2
done

[ $diff -eq 1 ] && return 1
[ $diff -eq 2 ] && return 2

return 3
}

# Set RPM build tree  
if [ -d /usr/src/redhat ]; then
        RPM_DIR=/usr/src/redhat
elif [ -d /usr/src/packages ]; then
        RPM_DIR=/usr/src/packages
else
        echo Build rpm on this system is not supported...
        exit 1
fi

make_config()
{
IFS=' '
# Configuration parameters initialization
touch $CONFIG

# Save previous configuration file
[ -s $CONFIG ] && $MV -f $CONFIG ${CONFIG}.save

cat $NULL > $CONFIG

echo STACK_PREFIX=$STACK_PREFIX >> $CONFIG
echo BUILD_ROOT=$BUILD_ROOT >> $CONFIG

if [ "$1" == "install" ]; then
    echo
    echo "Mandatory Packages:"
    echo
    IFS=';'
    for package in $REQUIRED_PACKAGES
    do
        pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
        pack_descr=`echo $package | cut -d ':' -f 2`
        echo ${pack}=y >> $CONFIG
        echo ${pack_descr} = y
    done
    IFS=' '

    echo
    echo "Select Packages To Install:"
    echo

    IFS=';'
    for package in $OPTIONAL_PACKAGES
    do
        pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
        pack_descr=`echo $package | cut -d ':' -f 2`
        echo -n "Install ${pack_descr}?[y/N]:"
        if get_ans; then
            echo ${pack}=y >> $CONFIG
        else
            echo ${pack}=n >> $CONFIG    
        fi
    done
    IFS=' '               
else   # case Uninstall
    if isInstalled openib; then
        echo -n "Do you want to remove all IBGD software?[y/N]:" 
        if ! get_ans; then

            IFS=';'
            for package in $REQUIRED_PACKAGES
            do
                pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                pack_descr=`echo $package | cut -d ':' -f 2`
                echo ${pack}=y >> $CONFIG
            done
            IFS=' '

            IFS=';'
            for package in $OPTIONAL_PACKAGES
            do
                pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                pack_descr=`echo $package | cut -d ':' -f 2`
                if isInstalled $pack; then
                    echo -n "Remove ${pack_descr}?[y/N]:"
                    if ! get_ans; then
                        echo ${pack}=y >> $CONFIG
                    else
                        echo ${pack}=n >> $CONFIG    
                    fi
                fi    
            done    
            IFS=' '                           
         else
            echo -n "Are you sure?[y/N]:"
            if get_ans; then
                IFS=';'
                for package in $REQUIRED_PACKAGES $OPTIONAL_PACKAGES
                do
                        pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                        echo ${pack}=n >> $CONFIG
                done
                IFS=' '
            else
                return 1
            fi        
         fi   
    else
        IFS=';'
        for package in $REQUIRED_PACKAGES $OPTIONAL_PACKAGES
        do
            pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
            echo ${pack}=n >> $CONFIG
        done
        IFS=' '

        warn_echo There is no IBGD packages installed
        getch
        source $CONFIG
        return 1
    fi    
fi  
  
source $CONFIG
return 0
}

# View installed packages
showInstalled()
{
local RC=0
  IFS=';'
  for package in $REQUIRED_PACKAGES $OPTIONAL_PACKAGES
  do
      pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
      if [ "$pack" == "thca" ]; then
          if ( $RPM -q ${THCA_NAME} > $NULL 2>&1 ); then
              local DESCR=`$RPM -qi ${THCA_NAME} | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q ${THCA_NAME}`
              echo
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
          elif [[ ! -z $MTHOME && -e $MTHOME/BUILD_ID ]]; then
              cat $MTHOME/BUILD_ID
              echo "THCA driver installed not in RPM format"
          fi 
      elif [ "$pack" == "mst" ]; then
          if ( $RPM -q ${MST_NAME}-${ARCH} > $NULL 2>&1 ); then
              local DESCR=`$RPM -qi ${MST_NAME}-${ARCH} | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q ${MST_NAME}-${ARCH}`
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
          fi    
      elif [ "$pack" == "mpi_ncsa" ]; then
          if ( $RPM -q  ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 ); then
              local DESCR=`$RPM -qi ${MPI_NCSA_VMI_NAME} | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q ${MPI_NCSA_VMI_NAME}`
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
              local DESCR=`$RPM -qi ${MPI_NCSA_MPICH_NAME} | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q ${MPI_NCSA_MPICH_NAME}`
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
          fi
      elif [ "$pack" == "mpi_osu" ]; then
          if ( $RPM -q  ${MPI_OSU_MPICH_NAME} > $NULL 2>&1 ); then
              local DESCR=`$RPM -qi ${MPI_OSU_MPICH_NAME} | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q ${MPI_OSU_MPICH_NAME}`
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
          fi
      else
          if ( $RPM -q $pack > $NULL 2>&1 ); then
              local DESCR=`$RPM -qi $pack | grep -A 1 Description | tail -1`
              local VERSION=`$RPM -q $pack`
              echo "NAME: $DESCR"  
              echo "VERSION: $VERSION"
              echo
              let RC++
          fi    
      fi    
  done
  IFS=' '
if [ $RC -eq 0 ]; then
    echo
    echo    There is no IBGD Software Installed
    echo
fi
  
  return 0
}


# Check $1 package RPM Build Requires ( Like kernel sources ... )
check_build_req()
{
IFS=' '
local RC=0
local mode=$2
local breq_pack
local breq_pack_name
local breq_pack_ver
local breq_pack_rel
local curr_pack_ver
    
    for breq_pack in `eval echo \$\{${1}_BUILD_REQ\}`
    do
        if ( echo $breq_pack | grep '_' > $NULL 2>&1 ); then
            breq_pack_name=`echo $breq_pack | cut -d '_' -f 1`
            breq_pack_ver=`echo $breq_pack | cut -d '_' -f 2`
            breq_pack_rel=`echo $breq_pack | cut -d '_' -f 3`
        else
            breq_pack_name=$breq_pack
            breq_pack_ver=""
            breq_pack_rel=""
        fi    
        
        if ! ( rpm -q $breq_pack_name > $NULL 2>&1 ); then
            [ "$mode" == "warn" ] && warn_echo "The $breq_pack_name package is required to build $1 RPM"
            [ "$mode" == "err" ] && err_echo "The $breq_pack_name package is required to build $1 RPM"
            let RC++
        else
            if [ "$breq_pack_ver" != "" ]; then
                curr_pack_ver=`$RPM --queryformat "[%{VERSION}]" -q $breq_pack_name`
                compare $breq_pack_ver $curr_pack_ver
                if [ $? -eq 1 ]; then
                    [ "$mode" == "warn" ] && warn_echo "The $breq_pack_name >= $breq_pack_ver package is required to build $1"
                    [ "$mode" == "err" ] && err_echo "The $breq_pack_name >= $breq_pack_ver package is required to build $1"
                    let RC++
                fi
            fi
        
        fi
    done
    
return $RC    
}


# Set FORTRAN environment for NCSA and OSU MPI
set_fortran_env()
{
IFS=' '
local NCSA_RPM=${MPI_NCSA_MPICH_NAME}-${MPI_NCSA_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm
local OSU_RPM=${MPI_OSU_MPICH_NAME}-${MPI_OSU_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm

if [[ -f ${RPMS}/${NCSA_RPM} && -f ${RPMS}/${OSU_RPM} ]]; then
    return 0
fi

if [[ "$mpi_ncsa" == "y" && "$mpi_osu" == "n" && -f ${RPMS}/${NCSA_RPM} ]]; then
   return 0
fi

if [[ "$mpi_ncsa" == "n" && "$mpi_osu" == "y" && -f ${RPMS}/${OSU_RPM} ]]; then
   return 0
fi

if [ $INTERACTIVE -eq 1 ]; then
    # Check if gcc-g77 package exists

    if ( $RPM -q gcc-g77 > $NULL 2>&1 ); then
        echo
        echo "A valid Fortran compiler should be present in order to build the MPI stack and tests."
        echo 
        echo "You have gcc-g77 Fortran compiler installed."
        echo -n "Would you like to use a different Fortran compiler?[y/N]:"
        if get_ans; then
            echo -n "Please provide the full path to the desired Fortran compiler 77:"
            read PGF_77
            while [ ! -x "$PGF_77" ]; do
                echo The file $PGF_77 does not exist
                echo -n "Please provide the full path to the desired Fortran compiler 77:"
                read PGF_77
            done
            
            echo -n "Please provide the full path to the desired Fortran compiler 90:"
            read PGF_90
            while [ ! -x "$PGF_90" ]; do
                echo The file $PGF_90 does not exist
                echo -n "Please provide the full path to the desired Fortran compiler 90:"
                read PGF_90
            done
            
            echo "PGF_77=$PGF_77" >> $CONFIG
            echo "PGF_90=$PGF_90" >> $CONFIG
        else    
            PGF_77=g77
            PGF_90=g77
        fi    
    else
        echo
        echo "In order to install NCSA or OSU MPI, a Fortran compiler must be installed."
        echo
        echo -n "Do you have a Fortran compiler installed?[y/n]:"
        if ! get_ans; then
            return 1
        fi    
        echo -n "Please provide the full path to the desired Fortran compiler 77:"
        read PGF_77
        while [ ! -x "$PGF_77" ]; do
            echo The file $PGF_77 does not exist
            echo -n "Please provide the full path to the desired Fortran compiler 77:"
            read PGF_77
        done
        
        echo -n "Please provide the full path to the desired Fortran compiler 90:"
        read PGF_90
        while [ ! -x "$PGF_90" ]; do
            echo The file $PGF_90 does not exist
            echo -n "Please provide the full path to the desired Fortran compiler 90:"
            read PGF_90
        done
        echo "PGF_77=$PGF_77" >> $CONFIG
        echo "PGF_90=$PGF_90" >> $CONFIG
        return 0
    fi
else
    # Check if gcc-g77 package exists
    if ( $RPM -q gcc-g77 > $NULL 2>&1 ); then
        if  [[ ! -z "$PGF_77" && ! -z "$PGF_90" ]]; then
            if  [[ ! -x "$PGF_77" || ! -x "$PGF_90" ]]; then
                echo
                warn_echo   "Fortran compilers $PGF_77 and $PGF_90 do not exist."
                warn_echo   "Using gcc-g77 compiler..."
                echo
            PGF_77=g77
            PGF_90=g77
            fi    
            return 0
        else    
            PGF_77=g77
            PGF_90=g77
            return 0
        fi    
    else # Check environment variables PGF_77 and PGF_90
        if  [[ ! -z "$PGF_77" && ! -z "$PGF_90" ]]; then
            if  [[ ! -x "$PGF_77" || ! -x "$PGF_90" ]]; then
                err_echo  "Fortran compilers $PGF_77 and $PGF_90 do not exist."
                return 1
            fi
            return 0
        else
            err_echo "Failed to find a Fortran compiler."  
            echo
            echo "Please set PGF_77 and PGF_90 variables in the $CONFIG file"
            echo
            return 1
        fi
    fi

fi
}

