#!/bin/bash                                 

# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS                               
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#
# Description: IBGD installation script
#

usage()
{
cat << EOF

    `basename $0` [ -c <packages config_file> ] [ -net <network config_file> ]

EOF
}

cd ${0%*/*}
CWD=`pwd`

INTERACTIVE=1
CONFIG=""
CONFIG_NET=""

if [ ! -e ./build_env.sh ]; then
    echo "ERROR: $CWD/build_env.sh file is missing"
    exit 1
fi

while [ $# -gt 0 ]
do
    case $1 in
            -c)
                shift
                CONFIG=$1
                INTERACTIVE=0
            ;;
	    -net)
	    	shift
		CONFIG_NET=$1
	    ;;
            *)
                usage
                exit 1
            ;;
    esac
    shift
done
                    

. $CWD/build_env.sh    

# Save installed RPMS and Backup previous versions
backup()
{
IFS=' '
if [ ! -d $BACKUP ]; then
    $MKDIR -p $BACKUP
fi

ex_silent "$RM -rf $PREV"
ex_silent "$RM -rf $BACKUPTMP"

if [ -d $CURR ]; then
    ex_silent "$CP -rf $CURR $PREV"
fi
ex_silent "$MKDIR -p $BACKUPTMP"
ex_silent "$MKDIR -p $BACKUPTMP/RPMS"

ex_silent "$CP `basename $0` $BACKUPTMP"
ex_silent "$CP build_env.sh $BACKUPTMP"
ex_silent "$CP $CONFIG $BACKUPTMP"
ex_silent "$CP -rf $SCRIPTS_SOURCE $BACKUPTMP"
}

# Remove installed packages in case of upgrade
rmInstalled()
{
IFS=' '
local RC=0
local OLD_PREFIX=""
echo
echo "Removing previous IBGD Software installations"
echo

    if ( $RPM -q ${MPI_OSU_MPICH_NAME} > $NULL 2>&1 ); then
        if [ "$mpi_osu" == "y" ]; then
            echo "OSU MPI will be reinstalled"
        else
            echo "OSU MPI will be uninstalled"
        fi    
        ex "$RPM -e ${MPI_OSU_MPICH_NAME}"
    fi    

    if ( $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 || $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 ); then
        if [ "$mpi_ncsa" == "y" ]; then
            echo "NCSA MPI will be reinstalled"
        else
            echo "NCSA MPI will be uninstalled"
        fi        
        $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 && ex "$RPM -e ${MPI_NCSA_MPICH_NAME}"
        $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 && ex "$RPM -e ${MPI_NCSA_VMI_NAME}"
    fi    
  
    if ( $RPM -q hmst-${ARCH} > $NULL 2>&1 ); then
        ex "$RPM -e hmst-${ARCH}"
    fi  
    
    if ( $RPM -q ${IBADM_NAME} > $NULL 2>&1 ); then
        if [ "$ibadm" == "y" ]; then
            echo "IBADM will be reinstalled"
        else
            echo "IBADM will be uninstalled"    
        fi    
        ex "$RPM -e ${IBADM_NAME}"
    fi    
 
    if ( $RPM -q ${MST_NAME}-${ARCH} > $NULL 2>&1 ); then
        if [ "$mst" == "y" ]; then
            echo "MST will be reinstalled"
        else
            echo "MST will be uninstalled"
        fi        
        ex "$RPM -e ${MST_NAME}-${ARCH}"
    fi    
   
    if ( $RPM -q ${OPENSM_NAME} > $NULL 2>&1 ); then
        if [ "$opensm" == "y" ]; then
            echo "Opensm will be reinstalled"
        else
            echo "Opensm will be uninstalled"    
        fi    
        ex "$RPM -e ${OPENSM_NAME}"
    fi    

    if ( $RPM -q ibtsal > $NULL 2>&1 ); then
        ex "$RPM -e ibtsal"
        let RC++
    fi    

    if ( $RPM -q thca-linux > $NULL 2>&1 ); then
        ex "$RPM -e thca-linux"
        let RC++
    fi    
    
    if ( $RPM -q ${OPENIB_NAME} > $NULL 2>&1 ); then
        if [ "$openib" == "y" ]; then
            echo "OPENIB will be reinstalled"
        else
            echo "OPENIB will be uninstalled"
        fi    
	OLD_PREFIX=`$RPM -ql ${OPENIB_NAME} | grep "utils/create_devs" | sed -e 's/\/utils\/create_devs//'`
        ex "$RPM -e ${OPENIB_NAME}"
        let RC++
    elif [[ ! -z $MTHOME && -d $MTHOME ]]; then
        if [ -e $MTHOME/uninstall.sh ]; then
            if [ "$openib" == "y" ]; then
                echo "OPENIB will be reinstalled"
            else
                echo "OPENIB will be uninstalled"
            fi    
            echo
            echo "  An old version of OPENIB driver is detected and will be removed now"
            ex "echo y | env MTHOME=$MTHOME $MTHOME/uninstall.sh"
        else
            echo
            echo "  An old version of OPENIB driver is detected in $MTHOME"
            echo "  Please remove it manually and unset MTHOME variable. Do logout and login to update environment variables"
            echo "  and then rerun INSTALL script"
            echo
            exit 3
        fi    
        let RC++
    elif [ -d /usr/mellanox ]; then
        if [ -e /usr/mellanox/uninstall.sh ]; then
            if [ "$openib" == "y" ]; then
                echo "MVAPI will be reinstalled with IBGD"
            else
                echo "MVAPI will be uninstalled"
            fi    
            echo
            echo "  Removing MVAPI..."
            ex "echo y | /usr/mellanox/uninstall.sh"
        else
            echo
            echo "  MVAPI driver is detected under /usr/mellanox directory"
            echo "  Please remove it manually"
            echo "  and then rerun INSTALL script"
            echo
            exit 3
        fi  
    fi    

    [ -d /usr/local/ib_hpc ] && ex_silent "$RM -rf /usr/local/ib_hpc"
    [ -d /usr/local/openib ] && ex_silent "$RM -rf /usr/local/openib"
    [ -d /usr/local/ibgd ] && ex_silent "$RM -rf /usr/local/ibgd"
    [ -d $STACK_PREFIX ] && ex_silent "$RM -rf $STACK_PREFIX"
    [ -d $OLD_PREFIX ] && ex_silent "$RM -rf $OLD_PREFIX"
   
    if [[ ! -d /etc/ibfw || ! -h /etc/ibfw ]]; then
        $RM -rf /etc/ibfw    
    fi  

    if [ $RC -gt 0 ]; then
        let NEED_REBOOT++
    fi
return 0
}

# Check if RPMs for selected packages exists
is_rpms()
{
IFS=' '

[ "$openib" == "y" ] && [ ! -f ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm ] && return 1
[ "$opensm" == "y" ] && [ ! -f ${RPMS}/${OPENSM_NAME}-${OPENSM_VER}-${RPMK_VER}.${build_arch}.rpm ] && return 1
[ "$mst" == "y" ] && [ ! -f ${RPMS}/${MST_NAME}-${ARCH}-${MST_VER}-${RPMK_VER}.${build_arch}.rpm ] && return 1
[ "$ibadm" == "y" ] && [ ! -f ${RPMS}/${IBADM_NAME}-${IBADM_VER}-${RPMK_VER}.${build_arch}.rpm ] && return 1
[ "$mpi_ncsa" == "y" ] && [[ ! -f ${RPMS}/${MPI_NCSA_VMI_NAME}-${MPI_NCSA_VMI_VER}-${RPMK_VER}.${build_arch}.rpm || ! -f ${RPMS}/${MPI_NCSA_MPICH_NAME}-${MPI_NCSA_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm ]] && return 1
[ "$mpi_osu" == "y" ] && [ ! -f ${RPMS}/${MPI_OSU_MPICH_NAME}-${MPI_OSU_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm ] && return 1
    
return 0
}

# Check $1 package requirments for running
check_run_req()
{
IFS=' '
local RC=0
local mode=$2
local rreq_pack
local rreq_pack_name
local rreq_pack_ver
local rreq_pack_rel
local curr_pack_ver

    for rreq_pack in  `eval echo \$\{${1}_RUN_REQ\}`
    do  
        if ( echo $rreq_pack | grep '_' > $NULL 2>&1 ); then
            rreq_pack_name=`echo $rreq_pack | cut -d '_' -f 1`          
            rreq_pack_ver=`echo $rreq_pack | cut -d '_' -f 2`
            rreq_pack_rel=`echo $rreq_pack | cut -d '_' -f 3`
        else
            rreq_pack_name=$rreq_pack
            rreq_pack_ver=""
            rreq_pack_rel=""
        fi
        
        if ! ( $RPM -q $rreq_pack_name > $NULL 2>&1 ); then
            [ "$mode" == "warn" ] && warn_echo "The $rreq_pack_name package is required to run $1"
            [ "$mode" == "err" ] && err_echo "The $rreq_pack_name package is required to run $1"
            let RC++
        else
            if [ "$rreq_pack_ver" != "" ]; then
                curr_pack_ver=`$RPM --queryformat "[%{VERSION}]" -q $rreq_pack_name`
                compare $rreq_pack_ver $curr_pack_ver
                if [ $? -eq 1 ]; then
                    [ "$mode" == "warn" ] && warn_echo "The $rreq_pack_name >= $rreq_pack_ver package is required  to run $1"
                    [ "$mode" == "err" ] && err_echo "The $rreq_pack_name >= $rreq_pack_ver package is required to run $1"
                    let RC++
                fi
            fi
        fi
    done
return $RC    
}

# Check if the package $1 is installed
isInstalled()
{
IFS=' '
case $1 in 
    mpi_osu)
        if ( $RPM -q ${MPI_OSU_MPICH_NAME} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;
    mpi_ncsa)
        if ( $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 || $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;
    ibadm)
        if ( $RPM -q ${IBADM_NAME} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;
    mst)
        if ( $RPM -q ${MST_NAME}-${ARCH} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;
    opensm)
        if ( $RPM -q ${OPENSM_NAME} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;
    openib)
        if ( $RPM -q ${OPENIB_NAME} > $NULL 2>&1 ); then
            return 0
        fi    
    ;;    
    *)
        if ( $RPM -q $1 > $NULL 2>&1 ); then
            return 0
        fi    
    ;;    
esac  

return 1
}

# Check if given IP address is valid
is_valid()
{
IFS=' '
local IP=$1
# Check for 3 dots a.b.c.d
if [ "`echo $IP | tr -d [:space:] | tr -d [:digit:] | wc -c`" -ne 3 ]; then
    return 1
fi

local A=`echo $IP | tr -d [:space:] | cut -d . -f 1`
if [ "`echo $A | tr -d [:digit:]`" != "" ]; then return 1;fi
local B=`echo $IP | tr -d [:space:] | cut -d . -f 2`
if [ "`echo $B | tr -d [:digit:]`" != "" ]; then return 1;fi
local C=`echo $IP | tr -d [:space:] | cut -d . -f 3`
if [ "`echo $C | tr -d [:digit:]`" != "" ]; then return 1;fi
local D=`echo $IP | tr -d [:space:] | cut -d . -f 4`    
if [ "`echo $D | tr -d [:digit:]`" != "" ]; then return 1;fi

return 0
}

# Configure IBADM parameters
ibadmconf()
{
IFS=' '
local NS_HOST_tmp
local IBBS_NAME_tmp
local LAN_INTERFACE_tmp

     LAN_INTERFACE_tmp=`$IFCONFIG | grep eth | awk '{print$1}' | sort -n | head -1 | tr -d [:space:]`
     LAN_INTERFACE=${LAN_INTERFACE:-$LAN_INTERFACE_tmp}
    
     NS_HOST_tmp=`$IFCONFIG | sed -e "/\($LAN_INTERFACE\).*/{ N; s/.*inet addr:\([0-9]*\.[0-9]*\.[0-9]*\.[0-9]*\).*/\1/; }" | grep ^[0-9] | head -1`
     if [ "${NS_HOST_tmp}" == "" ]; then
     	NS_HOST_tmp=11.0.0.1
     fi	
     IBBS_NAME_tmp="H-1"
     
     echo 
     echo "Please provide IBADM (Infiniband Administration Package) and OpenSM (Subnet Manager) configuration:"
     echo 
     
     echo -n "Enter IBADM Name Server and In-Band Server IP Address (one per IB subnet) [$NS_HOST_tmp]:"
     read NS_HOST
     if [ "$NS_HOST" == "" ]; then
         NS_HOST=$NS_HOST_tmp
     else     
         while ! is_valid $NS_HOST; do
             echo -n "Enter Valid Network like [$NS_HOST_tmp]:"
             read NS_HOST
             [ "$NS_HOST" == "" ] && NS_HOST=$NS_HOST_tmp
         done    
     fi    

     IBBS_HOST=$NS_HOST
     
     echo -n "Enter In-Band Server Hostname [$IBBS_NAME_tmp]:"
     read IBBS_NAME
     if [ "$IBBS_NAME" == "" ]; then
        IBBS_NAME=$IBBS_NAME_tmp
     fi   
        
     echo -n "Enter OpenSM Server IP Address [$IBBS_HOST]:"
     read OPENSM_HOST
     if [ "$OPENSM_HOST" == "" ]; then
         OPENSM_HOST=$IBBS_HOST
     else     
         while ! is_valid $OPENSM_HOST; do
             echo -n "Enter Valid Network like [$IBBS_HOST]:"
             read OPENSM_HOST
             [ "$OPENSM_HOST" == "" ] && OPENSM_HOST=$IBBS_HOST
         done    
     fi    

     # Set FW_WORK_DIR
     echo -n "Enter firmware work directory [/tmp]:"
     read FW_WORK_DIR
     if [ "$FW_WORK_DIR" == "" ]; then
           FW_WORK_DIR="/tmp"
     else      
         while [[ "$FW_WORK_DIR" == "/" || "$FW_WORK_DIR" == "/root" ]]; do
             err_echo "Invalid directory."
             echo -n "Enter firmware work directory [/tmp]:"
             read FW_WORK_DIR
             [ "$FW_WORK_DIR" == "" ] && FW_WORK_DIR="/tmp"
         done
     fi    

     
# Clean previous IBADM configuration in order to prevent duplicate IP
perl -ni -e 'if (/\#\# IBADM \#\#$/) { $filter = 1 }' -e 'if (!$filter) { print }' -e 'if (/\#\# END IBADM \#\#$/){ $filter = 0 }' $CONFIG

echo "## IBADM ##" >> $CONFIG
echo LAN_INTERFACE=$LAN_INTERFACE >> $CONFIG
echo NS_HOST=$NS_HOST >> $CONFIG
echo IBBS_HOST=$IBBS_HOST >> $CONFIG
echo IBBS_NAME=$IBBS_NAME >> $CONFIG
echo OPENSM_HOST=$OPENSM_HOST >> $CONFIG
echo FW_WORK_DIR=$FW_WORK_DIR >> $CONFIG
echo "## END IBADM ##" >> $CONFIG

return 0
}

# Check if ETH interface $1 exists
is_eth()
{
IFS=' '
    local eth_name=$1
    shift
    
    $IFCONFIG $eth_name > $NULL 2>&1   
    return $?
}

# Configure Driver Autostart
ipconfig()
{
IFS=' '
local device=$1
      shift
local target=$1
      shift

# Set default network configuration
local IPADDR IPADDR_tmp
local NETMASK NETMASK_tmp
local BROADCAST BROADCAST_tmp
local NETWORK NETWORK_tmp 
local ONBOOT ONBOOT_tmp=1
local LAN_INTERFACE LAN_INTERFACE_tmp
local INTERFACES INTERFACE ADDRS


INTERFACES=`$IFCONFIG | grep eth | awk '{print$1}' | sort -n | tr -s '\n' '\ '`
for INTERFACE in $INTERFACES
do
        if ( $IFCONFIG $INTERFACE | grep "inet addr" > $NULL 2>&1 ); then
              LAN_INTERFACE_tmp=$INTERFACE
              break
        fi
done

LAN_INTERFACE_tmp=${LAN_INTERFACE_tmp:-eth0}

    # Set Ethernet device for IPoIB configuration
    LAN_INTERFACE=`eval echo \$\{LAN_INTERFACE_$device\}`

    if [ $INTERACTIVE -eq 1 ]; then
       echo
       read -p "Enter LAN interface to be used for setting $device interface [$LAN_INTERFACE_tmp]:"
       LAN_INTERFACE=${REPLY:-eth0}
       while ! is_eth $LAN_INTERFACE; do
            read -p "Enter existing LAN interface to be used for setting $device interface [$LAN_INTERFACE_tmp]:"
            LAN_INTERFACE=${REPLY:-eth0}
       done 
    else
       LAN_INTERFACE=${LAN_INTERFACE:-$LAN_INTERFACE_tmp}
    fi



local high_IP=`$IFCONFIG | sed -e "/\($LAN_INTERFACE\).*/{ N; s/.*inet addr:\([0-9]*\).*/\1/; }" | grep ^[0-9] | head -1`
if [ "${high_IP}" == "" ]; then
	high_IP=10
fi
let high_IP=$high_IP+$IP_cnt

local low_IP=`$IFCONFIG | sed -e "/\($LAN_INTERFACE\).*/{ N; s/.*inet addr:[0-9]*\.\([0-9]*\.[0-9]*\.[0-9]*\).*/\1/; }" | grep ^[0-9] | head -1`
if [ "${low_IP}" == "" ]; then
	low_IP=0.0.1
fi
IPADDR_tmp=${high_IP}.${low_IP}

NETMASK_tmp=`$IFCONFIG | sed -e "/\($LAN_INTERFACE\).*/{ N; s/.*Mask:\([0-9]*\.[0-9]*\.[0-9]*\.[0-9]*\).*/\1/; }" | grep ^[0-9] | head -1`
if [ "${NETMASK_tmp}" == "" ]; then
	NETMASK_tmp=255.0.0.0
fi

local low_Bcast=`$IFCONFIG | sed -e "/\($LAN_INTERFACE\).*/{ N; s/.*Bcast:[0-9]*\.\([0-9]*\.[0-9]*\.[0-9]*\).*/\1/; }" | grep ^[0-9] | head -1`
if [ "${low_Bcast}" == "" ]; then
	low_Bcast=0.255.255
fi
BROADCAST_tmp=${high_IP}.${low_Bcast}

#################################################################

IP_A=`echo ${IPADDR_tmp} | cut -d '.' -f 1 | tr -d [:space:]`
IP_B=`echo ${IPADDR_tmp} | cut -d '.' -f 2 | tr -d [:space:]`
IP_C=`echo ${IPADDR_tmp} | cut -d '.' -f 3 | tr -d [:space:]`
IP_D=`echo ${IPADDR_tmp} | cut -d '.' -f 4 | tr -d [:space:]`

NM_A=`echo ${NETMASK_tmp} | cut -d '.' -f 1 | tr -d [:space:]`
NM_B=`echo ${NETMASK_tmp} | cut -d '.' -f 2 | tr -d [:space:]`
NM_C=`echo ${NETMASK_tmp} | cut -d '.' -f 3 | tr -d [:space:]`
NM_D=`echo ${NETMASK_tmp} | cut -d '.' -f 4 | tr -d [:space:]`

NW_A=$[ $IP_A & $NM_A ]
NW_B=$[ $IP_B & $NM_B ]
NW_C=$[ $IP_C & $NM_C ]
NW_D=$[ $IP_D & $NM_D ]

NETWORK_tmp=${NW_A}.${NW_B}.${NW_C}.${NW_D}

local ip=""
local nm=""
local nw=""
local bc=""
 
if [ $INTERACTIVE -eq 1 ]; then
   echo
   echo "$device configuration:"

        if [ -s $NETWORK_CONF_DIR/ifcfg-$device ]; then
            echo
            echo "  Current IPOIB configuration for $device"
            echo
            cat $NETWORK_CONF_DIR/ifcfg-$device
            echo
            echo -n "Do you want to change this configuration?[y/N]:"
            if ! get_ans; then
                # echo
                # pass_echo "Saved current configuration (/etc/infiniband/ifcfg-${device}.rpmsave) for $device"
                # echo
                return 0
            fi
        fi
        

            echo -n "Enter IP Address [$IPADDR_tmp]:"
            read ip
            if [ "$ip" == "" ]; then
                IPADDR=$IPADDR_tmp            
            else
                while ! is_valid $ip; do
                    echo -n "Enter valid IP Address like [$IPADDR_tmp]:"
                    read ip
                done    
                IPADDR=$ip
            fi
            
            echo -n "Enter Netmask [$NETMASK_tmp]:"
            read nm
            if [ "$nm" == "" ]; then
                NETMASK=$NETMASK_tmp
            else                  
                while ! is_valid $nm; do
                    echo -n "Enter Valid Netmask like [$NETMASK_tmp]:"
                    read nm
                done    
                NETMASK=$nm
            fi    
                
            echo -n "Enter Network [$NETWORK_tmp]:"
            read nw
            if [ "$nw" == "" ]; then
                NETWORK=$NETWORK_tmp
            else     
                while ! is_valid $nw; do
                    echo -n "Enter Valid Network like [$NETWORK_tmp]:"
                    read nw
                done    
                NETWORK=$nw
            fi    
            
            echo -n "Enter Broadcast [$BROADCAST_tmp]:"
            read bc
            if [ "$bc" == "" ]; then
                BROADCAST=$BROADCAST_tmp
            else     
                while ! is_valid $bc; do
                    echo -n "Enter Valid Network like [$BROADCAST_tmp]:"
                    read bc
                done    
                BROADCAST=$bc
            fi    
            
            read -p "Start Device On Boot?[Y/n]:" ans
            if ! [[ "$ans" == "" || "$ans" == "y" || "$ans" == "Y" || "$ans" == "yes" ]]; then
                ONBOOT=0
            else
                ONBOOT=1    
            fi
#         fi

            
            echo
            echo Selected configuration:
            echo
            echo IPADDR=$IPADDR
            echo NETMASK=$NETMASK
            echo NETWORK=$NETWORK
            echo BROADCAST=$BROADCAST
            if [ $ONBOOT -eq 1 ]; then
                 echo ONBOOT=yes
            else
                 echo ONBOOT=no
            fi

            echo
            echo -n "Do you want to save selected configuration?[Y/n]:"
            read ans
            if ! [[ "$ans" == "" || "$ans" == "y" || "$ans" == "Y" || "$ans" == "yes" ]]; then
                return 1
            fi    
            
else # Non interactive mode

if [ -e ${target}.rpmsave ]; then
	if ( /usr/bin/diff ${target}.rpmsave ${target} > $NULL 2>&1 ); then
		pass_echo "Used the previous configuration file (${target}.rpmsave) for $device interface"
		return 0
	fi	
fi
	
    # Set device configuration from config file
    IPADDR=`eval echo \$\{IPADDR_$device\}`
    NETMASK=`eval echo \$\{NETMASK_$device\}`
    NETWORK=`eval echo \$\{NETWORK_$device\}`
    BROADCAST=`eval echo \$\{BROADCAST_$device\}`
    ONBOOT=`eval echo \$\{ONBOOT_$device\}`
               

    # If "A" in calculated IP (A.B.C.D) address same as IP from config file use calculated IP, otherwise use an IP from config file
    if [[ -z ${IPADDR} || "${IPADDR%*.*.*.*}" == "${IPADDR_tmp%*.*.*.*}" ]]; then
        IPADDR=$IPADDR_tmp
    fi    
    
    NETMASK=${NETMASK:-$NETMASK_tmp}
    NETWORK=${NETWORK:-$NETWORK_tmp}
    BROADCAST=${BROADCAST:-$BROADCAST_tmp}
    ONBOOT=${ONBOOT:-$ONBOOT_tmp}

    echo
    echo "IPoIB configuration for $device:"
    echo
    echo IPADDR=$IPADDR
    echo NETMASK=$NETMASK
    echo NETWORK=$NETWORK
    echo BROADCAST=$BROADCAST
    if [ $ONBOOT -eq 1 ]; then
        echo ONBOOT=yes
    else
        echo ONBOOT=no
    fi
fi    

cat $NULL > $target

if [ "$DISTRIBUTION" == "SuSE" ]; then
    echo BOOTPROTO=\'static\' >> $target
    echo IPADDR=\'${IPADDR}\' >> $target
    echo NETMASK=\'$NETMASK\' >> $target
    echo NETWORK=\'${NETWORK}\' >> $target
    echo BROADCAST=\'${BROADCAST}\' >> $target
    echo REMOTE_IPADDR=\'\' >> $target
    if [ $ONBOOT -eq 1 ]; then
        echo STARTMODE=\'onboot\' >> $target
    else
        echo STARTMODE=\'manual\' >> $target
    fi    
    echo WIRELESS=\'no\' >> $target
else
    echo DEVICE=$DEVICE >> $target
    echo BOOTPROTO=static >> $target
    echo IPADDR=${IPADDR} >> $target
    echo NETMASK=$NETMASK >> $target
    echo NETWORK=${NETWORK} >> $target
    echo BROADCAST=${BROADCAST} >> $target
    if [ $ONBOOT -eq 1 ]; then
        echo ONBOOT=yes >> $target
    else
        echo ONBOOT=no >> $target    
    fi        
fi


if [ $SET_CONFIG_NET -eq 1 ]; then                                
    echo LAN_INTERFACE_$device=$LAN_INTERFACE >> $CONFIG_NET
    echo IPADDR_$device=$IPADDR >> $CONFIG_NET
    echo NETMASK_$device=$NETMASK >> $CONFIG_NET
    echo NETWORK_$device=$NETWORK >> $CONFIG_NET
    echo BROADCAST_$device=$BROADCAST >> $CONFIG_NET
    echo ONBOOT_$device=$ONBOOT >> $CONFIG_NET
fi

chown root $target
chgrp root $target
chmod ugo=r,u=rw $target

}


set_ip()
{
IFS=' '
DEVICES="ib0 ib1"
if ( /sbin/lspci -n | grep "15b3:5e8c" > /dev/null ); then # Sinai
        DEVICES="ib0"
fi

IP_cnt=1

if [ $SET_CONFIG_NET -eq 1 ]; then                                
    # Clean IPOIB configuration file
#    perl -ni -e 'if (/\#\# IPOIB \#\#$/) { $filter = 1 }' -e 'if (!$filter) { print }' -e 'if (/\#\# END IPOIB \#\#$/){ $filter = 0 }' $CONFIG_NET

    echo "## IPOIB ##" > $CONFIG_NET
fi

if [ $INTERACTIVE -eq 1 ]; then
    echo
    echo "The default IPoIB interface configuration is based on a LAN interface configuration."
    echo "You may change this default configuration in the following steps."    
fi

for DEVICE in $DEVICES
do
   target=$NETWORK_CONF_DIR/ifcfg-${DEVICE}
   ipconfig $DEVICE $target
   let IP_cnt++
done

if [ $SET_CONFIG_NET -eq 1 ]; then                                
    echo "## END IPOIB ##" >> $CONFIG_NET
fi    

if [ $INTERACTIVE -eq 1 ]; then
    echo
    pass_echo "IPOIB interface configured successfully"
    echo
        
    # Set IBADM configuration
    ibadmconf
    pass_echo "IBADM and OpenSM configured successfully"
    getch
fi
}

# HCA driver and Ulps installation
openib()
{
IFS=' '
if [ -f ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
    if ! check_run_req openib err; then
        exit 2
    fi    
    ex "$RPM -ihv ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm"
#    ex "$CP ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm not found"
    return 1
fi

# Set permissions
$CHMOD -R +rw ${OPENIB_DEST}

return 0
}


# OpenSM installation
opensm()
{
IFS=' '
if [ -f ${RPMS}/${OPENSM_NAME}-${OPENSM_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
    if ! check_run_req opensm err; then
        exit 2
    fi    
    ex "$RPM -ihv ${RPMS}/${OPENSM_NAME}-${OPENSM_VER}-${RPMK_VER}.${build_arch}.rpm"
#    ex "$CP ${RPMS}/${OPENSM_NAME}-${OPENSM_VER}-${RPMK_VER}.${build_arch}.rpm ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${OPENSM_NAME}-${OPENSM_VER}-${RPMK_VER}.${build_arch}.rpm not found"
    return 1
fi

return 0
}

# HCA Tools installation
mst()
{
IFS=' '
if [ -f ${RPMS}/${MST_NAME}-${ARCH}-${MST_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
    if ! check_run_req mst err; then
        return 2
    fi    
    ex "$RPM -ihv ${RPMS}/${MST_NAME}-${ARCH}-${MST_VER}-${RPMK_VER}.${build_arch}.rpm"
#    ex "$CP ${RPMS}/${MST_NAME}-${ARCH}-${MST_VER}-${RPMK_VER}.${build_arch}.rpm ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${MST_NAME}-${ARCH}-${MST_VER}-${RPMK_VER}.${build_arch}.rpm not found"
    return 1
fi

return 0
}

# IBADM installation
ibadm()
{
IFS=' '
if [ -f ${RPMS}/${IBADM_NAME}-${IBADM_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
    if ! check_run_req ibadm err; then
        exit 2
    fi    
    ex "$RPM -ihv ${RPMS}/${IBADM_NAME}-${IBADM_VER}-${RPMK_VER}.${build_arch}.rpm"
#    ex "$CP ${RPMS}/${IBADM_NAME}-${IBADM_VER}-${RPMK_VER}.${build_arch}.rpm ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${IBADM_NAME}-${IBADM_VER}-${RPMK_VER}.${build_arch}.rpm not found"
    return 1
fi

return 0
}

             
# NCSA MPI installation
mpi_ncsa()
{
IFS=' '
local VMI_RPM=${MPI_NCSA_VMI_NAME}-${MPI_NCSA_VMI_VER}-${RPMK_VER}.${build_arch}.rpm
local NCSA_RPM=${MPI_NCSA_MPICH_NAME}-${MPI_NCSA_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm

# Add libcurl.so link (W/A for Rocks 0.3.3)

if [ -d /usr/lib ]; then
        if [ ! -h /usr/lib/libcurl.so ]; then
                cd /usr/lib
                ln -snf libcurl.so.2.0.2 libcurl.so
                cd -
        fi
fi

if [ -d /usr/lib64 ]; then
        if [ ! -h /usr/lib64/libcurl.so ]; then
                cd /usr/lib64
                ln -snf libcurl.so.2.0.2 libcurl.so
                cd -
        fi
fi


if [[ -f ${RPMS}/${VMI_RPM} && -f ${RPMS}/${NCSA_RPM} ]]; then
    if ! check_run_req mpi_ncsa err; then
        return 2
    fi    
    ex "$RPM -ihv ${RPMS}/${VMI_RPM} ${RPMS}/${NCSA_RPM}"
#    ex "$CP ${RPMS}/${VMI_RPM} ${RPMS}/${NCSA_RPM} ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${VMI_RPM} and ${RPMS}/${NCSA_RPM} not found"
    return 1
fi

return 0
}

# OSU MPI installation
mpi_osu()
{
IFS=' '
local OSU_RPM=${MPI_OSU_MPICH_NAME}-${MPI_OSU_MPICH_VER}-${RPMK_VER}.${build_arch}.rpm

if [ -f ${RPMS}/${OSU_RPM} ]; then
    if ! check_run_req mpi_osu err; then
        return 2
    fi    
    ex "$RPM -ihv ${RPMS}/${OSU_RPM}"
#    ex "$CP ${RPMS}/${OSU_RPM} ${BACKUPTMP}/RPMS"
else
    err_echo "${RPMS}/${OSU_RPM} not found"
    return 1
fi

return 0
}


make_install()
{
IFS=' '
#backup
rmInstalled

echo
echo "Installing IBGD software"
echo

IFS=';'
for package in $REQUIRED_PACKAGES $OPTIONAL_PACKAGES
do
      pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
      if [ "`eval echo \$\{${pack}\}`" == "y" ]; then   
            if ! $pack; then
                err_echo "Failed to install $pack"
                exit 1
            fi    
      fi
done
IFS=' '
  
ex_silent "$CP -rf $DOCS_SOURCE $STACK_PREFIX"
ex_silent "$CP $PKG_SOURCE_DIR/README.txt $STACK_PREFIX/README.txt"
ex_silent "$CP $PKG_SOURCE_DIR/BUILD_ID $STACK_PREFIX/BUILD_ID"
ex_silent "$CP $PKG_SOURCE_DIR/LICENSE $STACK_PREFIX/LICENSE"

ex_silent "$CP $CONFIG $STACK_PREFIX/"
ex_silent "$CP $PKG_SOURCE_DIR/uninstall.sh $STACK_PREFIX/uninstall.sh"

perl -ni -e "s@(STACK_PREFIX=).*@\$1${STACK_PREFIX}@; print" $STACK_PREFIX/uninstall.sh

# Create scripts directory and links from /usr/bin
ex_silent "$CP -rf $SCRIPTS_SOURCE/scripts $STACK_PREFIX"

cd /usr/bin

for bin in $STACK_PREFIX/scripts/*
do
     ex_silent "ln -snf $bin"
done

cd -

return 0
}

# Uninstall Software
uninstall()
{
IFS=' '
if [ $INTERACTIVE -eq 1 ]; then
   if ! make_config uninstall; then
    	return 1
   fi
fi
    
local RC=0
   
   if [ "$mpi_osu" != "y" ]; then
    if ( $RPM -q ${MPI_OSU_MPICH_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${MPI_OSU_MPICH_NAME}"
        let RC++
    fi    
   fi 
   
   if [ "$mpi_ncsa" != "y" ]; then
    if ( $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${MPI_NCSA_MPICH_NAME}"
        let RC++
    fi    
     
    if ( $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${MPI_NCSA_VMI_NAME}"
    fi   
   fi 

   if [ "$ibadm" != "y" ]; then
    if ( $RPM -q ${IBADM_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${IBADM_NAME}"
        let RC++
    fi    
   fi 
   
   if [ "$mst" != "y" ]; then
    if ( $RPM -q hmst-${ARCH} > $NULL 2>&1 ); then
        ex "$RPM -e hmst-${ARCH}"
    fi 
	
    if ( $RPM -q ${MST_NAME}-${ARCH} > $NULL 2>&1 ); then
        ex "$RPM -e ${MST_NAME}-${ARCH}"
        let RC++
    fi    
   fi 
   
   if [ "$opensm" != "y" ]; then
    if ( $RPM -q ${OPENSM_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${OPENSM_NAME}"
        let RC++
    fi    
   fi 

   if [ "$openib" != "y" ]; then
    if ( $RPM -q ${OPENIB_NAME} > $NULL 2>&1 ); then
        ex "$RPM -e ${OPENIB_NAME}"
        let RC++
    fi
        # Remove IBGD software the from system    
        $RM -rf $STACK_PREFIX
        $RM -f $NETWORK_CONF_DIR/ifcfg-ib*
        if [[ ! -d /etc/ibfw || ! -h /etc/ibfw ]]; then
            $RM -rf /etc/ibfw    
        fi 
   fi

    [ -d /usr/local/ib_hpc ] && ex_silent "$RM -rf /usr/local/ib_hpc"
    [ -d /usr/local/openib ] && ex_silent "$RM -rf /usr/local/openib"
    [ -d /usr/local/ibgd ] && ex_silent "$RM -rf /usr/local/ibgd"
    [ -d $STACK_PREFIX ] && ex_silent "$RM -rf $STACK_PREFIX"

if [ $INTERACTIVE -eq 1 ]; then
    if [ $RC -gt 0 ]; then
        echo
        pass_echo "$RC packages were removed successfully"
        echo
#         echo "  Please reboot the system ..."
#         echo
        getch
    else 
        echo
        warn_echo "No packages selected to be removed"
        getch    
    fi    
fi
return 0
}

# Edit /etc/opensm.conf and /etc/ibadm.conf files
set_configs()
{
IFS=' '
# Edit /etc/ibadm.conf
if [[ ! -z "$IBBS_HOST" && ! -z "$NS_HOST" && ! -z "$IBBS_NAME" ]]; then
#   if [ ! -e /etc/ibadm.conf.rpmsave ]; then
    	eval "sed -e 's/IBBS_HOST=.*/IBBS_HOST=${IBBS_HOST}/g' -e 's/IBBS_NAME=.*/IBBS_NAME=${IBBS_NAME}/g' -e 's/NS_HOST=.*/NS_HOST=${NS_HOST}/g' /etc/ibadm.conf" > /tmp/ibadm.conf.tmp
	ex_silent "$MV -f /tmp/ibadm.conf.tmp /etc/ibadm.conf"
#   else
#        # Check that ibadm.conf.rpmsave has relevant values ( not 0.0.0.0 )
#	if [ "`grep IBBS_HOST= /etc/ibadm.conf.rpmsave | cut -d = -f 2 | tr -d [:space:]`" == "0.0.0.0" ]; then
#		perl -ni -e "s@^(IBBS_HOST=).*@\${1}${IBBS_HOST}@; print" /etc/ibadm.conf
#	fi
#	if [ "`grep IBBS_NAME= /etc/ibadm.conf.rpmsave | cut -d = -f 2 | tr -d [:space:]`" == "H-1" ]; then
#		perl -ni -e "s@^(IBBS_NAME=).*@\${1}${IBBS_NAME}@; print" /etc/ibadm.conf
#	fi
#	if [ "`grep NS_HOST= /etc/ibadm.conf.rpmsave | cut -d = -f 2 | tr -d [:space:]`" == "0.0.0.0" ]; then
#		perl -ni -e "s@^(NS_HOST=).*@\${1}${NS_HOST}@; print" /etc/ibadm.conf
#	fi
#	
#
#   	# pass_echo "Used the previous configuration file (/etc/ibadm.conf.rpmsave) for ibadm"
#   fi 
    
    # Open ibfw tgz in the IBBS Host
    if [[ -n "`$IFCONFIG | grep -w $IBBS_HOST`" || -n "`grep -rw $IBBS_HOST ${NETWORK_CONF_DIR}`" ]]; then
        [ ! -d $FW_DEST/FW ] && ex_silent "$MKDIR -p $FW_DEST/FW"
        echo
        echo "Creating FW directory to be used by IBADM server"
        echo
        
        cd $FW_DEST/FW
        ex "tar xzvf $IBFW"
        pass_echo "$FW_DEST/FW directory updated with new FW release"
        cd -
        if [[ ! -d /etc/ibfw || ! -h /etc/ibfw ]]; then
            ex_silent "ln -snf $FW_DEST/FW/${IBFW_NAME%*.*}  /etc/ibfw"
        fi    
    fi
fi

# Check FW_WORK_DIR
if [ ! -z "$FW_WORK_DIR" ]; then
    if [ ! -d  "$FW_WORK_DIR" ]; then
        mkdir -p $FW_WORK_DIR
        if [ $? -ne 0 ]; then
            err_echo "Failed to create $FW_WORK_DIR. Please create it manually"
        fi    
    fi
    perl -ni -e "s@(FW_WORK_DIR=).*@\$1${FW_WORK_DIR}@; print" /etc/ibadm.conf
fi



# Edit /etc/opensm.conf
if [ ! -z "$OPENSM_HOST" ]; then
    if [[ -n "`$IFCONFIG | grep -w $OPENSM_HOST`"  || -n "`grep -rw $OPENSM_HOST ${NETWORK_CONF_DIR}`" ]]; then
        perl -ni -e "s@^(ONBOOT=).*@\${1}yes@; print" /etc/opensm.conf
    else
        perl -ni -e "s@^(ONBOOT=).*@\${1}no@; print" /etc/opensm.conf
    fi
fi

return 0
}

# Ulps onboot configuration
ulps_config()
{
echo
}

# Main

main()
{
IFS=' '
check_user

# Set network environment configuration
NETWORK_CONF_DIR="/etc/infiniband"

if [ -f /etc/SuSE-release ]; then
    DISTRIBUTION="SuSE"
    
    # Check termcap library link
    if [[ ! -e /usr/lib/libtermcap.so && -e /usr/lib/libtermcap.so.2.0.8 ]]; then
        ex_silent "ln -snf /usr/lib/libtermcap.so.2.0.8 /usr/lib/libtermcap.so"
    fi
    
elif [ -f /etc/redhat-release ]; then
    DISTRIBUTION="redhat"

elif [ -f /etc/rocks-release ]; then
    DISTRIBUTION="Rocks"
else
    DISTRIBUTION=`ls /etc/*-release | head -n 1 | xargs -iXXX basename XXX -release 2> /dev/null`
fi

# Check if Infiniband driver was loaded
if ( $LSMOD | grep mosal > $NULL ); then
    let NEED_REBOOT++
fi

		     
# Check STACK_PREFIX for existing RPMs
if [ -e ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
	STACK_PREFIX=`$RPM -qlp ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm | grep "utils/create_devs" | sed -e 's/\/utils\/create_devs//'`
	. $CWD/build_env.sh    
fi

if [ $INTERACTIVE -eq 1 ]; then
   show_menu "main_menu"
	
        read ans_inst
        case $ans_inst in
                2)   
                
                     echo
                     echo "Checking dependencies. Please wait ..."
                     echo
                            
                     # Check for Infiniband software of other vendors
                     local vendors="topspin iview_fm"
                     local vrpms=""
                     
                     for vendor in $vendors
                     do
                        vrpms=`$RPM -qa | grep $vendor`
                        if [ -n "$vrpms" ]; then
                            echo
                            err_echo "You have to remove ${vendor} Infiniband software before continuing:"
                            echo
                            echo "$vrpms"
                            echo
                            exit 9
                        fi
                     done
                    
                     # Check dependencies and print Warning messages
                     local req_status=0
                     
                     IFS=';'
                     for package in $REQUIRED_PACKAGES
                     do
                             pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                             
                             check_run_req $pack err
                             let req_status=$req_status+$?
                     done
                     IFS=' '
                     
                     IFS=';'
                     for package in $OPTIONAL_PACKAGES
                     do
                             pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                             check_run_req $pack warn
                     done
                     IFS=' '
                     
                     # Exit if there is missing required software for mandatory packages
                     if [ $req_status -gt 0 ]; then
                        exit 7
                     fi   
                     
                     if isInstalled "thca-linux" || isInstalled "openib"; then
                         echo
                         warn_echo "This installation program will remove any previously installed IB packages on your machine."
                         echo
                         read -p "Do you want to continue?[Y/n]:" ans_r
                         if ! [[ "$ans_r" == "" || "$ans_r" == "y" || "$ans_r" == "Y" || "$ans_r" == "yes" ]]; then
                             return 1
                         fi
                     fi
                     
                     # Print IBGD Package content
                     echo 
                     echo " IBGD Software Packages:"
                     echo
                     echo " The following packages will be installed:"
                     echo
                     IFS=';'
                     for package in $REQUIRED_PACKAGES
                     do
                             p_name=`echo $package | cut -d : -f 2`
                             echo "     $p_name"
                     done
                     IFS=' '
                     echo
                     echo " The following packages are optional:"
                     echo
                     IFS=';'
                     for package in $OPTIONAL_PACKAGES
                     do
                             p_name=`echo $package | cut -d : -f 2`
                             echo "     $p_name"
                     done
                     IFS=' '
		     
		     # Check STACK_PREFIX for existing RPMs
		     if [ -e ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm ]; then
			STACK_PREFIX=`$RPM -qlp ${RPMS}/${OPENIB_NAME}-${OPENIB_VER}-${RPMK_VER}.${build_arch}.rpm | grep "utils/create_devs" | sed -e 's/\/utils\/create_devs//'`
			. $CWD/build_env.sh    
		     fi
                     echo   
                     echo
                     echo "The default installation directory for IBGD Software is ${STACK_PREFIX}"
                     read -p "Do you want to continue? [Y/n]:" ans_r
                     if ! [[ "$ans_r" == "" || "$ans_r" == "y" || "$ans_r" == "Y" || "$ans_r" == "yes" ]]; then
                         return 1
                     fi
                        
                     make_config install
                     
                     # Check if all required RPM packages exists
                     # If not, run build.sh script with created configuration file
                     if ! is_rpms; then
                        
                        echo
                        pass_echo "Preparing to build the IBGD RPMs:"
                        echo

                             # Check dependencies and print Warning messages
                             # Check if kernel sources exists (needed for packages compilation)
                             if ! test -d /lib/modules/${K_VER}/build; then
                                 echo
                                 warn_echo "There is no sources for ${K_VER} kernel installed.
                                            Please install ${K_VER} kernel sources to build RPMs on this system"
                                 echo
                                 getch
                             fi
                             
                             local req_status=0
               
                             IFS=';'
                             for package in $REQUIRED_PACKAGES
                             do
                                 pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                                 check_build_req $pack err
                                 let req_status=$req_status+$?
                             done
                             IFS=' '
                             
                             IFS=';'
                             for package in $OPTIONAL_PACKAGES
                             do
                                 pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                                 check_build_req $pack warn
                             done
                             IFS=' '
                             
                             # Exit if there is missing required software for mandatory packages
                             if [ $req_status -gt 0 ]; then
                                getch
                                exit 7
                             fi   

                        echo
                        echo "RPM build process uses a temporary directory."
                        echo
                        read -p "Please enter the temporary directory [${BUILD_ROOT}]:"
                        BUILD_ROOT=${REPLY:-$BUILD_ROOT}

                        if [ "${BUILD_ROOT}" != "${BUILD_ROOT_DFT}" ]; then
                               BUILD_ROOT=${BUILD_ROOT}/IBGD
                        fi
                        
                        [ -d $BUILD_ROOT ] && ex_silent "$RM -rf $BUILD_ROOT"
                        
                        check_space_req "$BUILD_SPACE_REQ" "$BUILD_ROOT"
                        
                        echo
                        read -p "Please enter IBGD installation directory [${STACK_PREFIX}]:"
                        STACK_PREFIX=${REPLY:-$STACK_PREFIX}

                        # Set  parameters with new values
                        . $CWD/build_env.sh
                        
                        check_space_req "$RUN_SPACE_REQ" "$STACK_PREFIX"

                        if [[ "$mpi_ncsa" == "y" || "$mpi_osu" == "y" ]]; then
                            # Set fortran environment for MPI                                    
                            if ! set_fortran_env; then
                                 warn_echo "Failed to locate Fortran compiler. OSU and NCSA MPI will not be installed"
                                 export mpi_ncsa=n
                		 export mpi_osu=n
                            fi   
                        fi

                        # Update CONFIG file
                        perl -ni -e "s@(BUILD_ROOT=).*@\$1${BUILD_ROOT}@; print" $CONFIG
                        perl -ni -e "s@(STACK_PREFIX=).*@\$1${STACK_PREFIX}@; print" $CONFIG
                        perl -ni -e "s@(mpi_ncsa=).*@\$1${mpi_ncsa}@; print" $CONFIG
                        perl -ni -e "s@(mpi_osu=).*@\$1${mpi_osu}@; print" $CONFIG
                        
                        
                        ${CWD}/build.sh -c $CONFIG
                        if [ $? -ne 0 ]; then
                            exit 1
                        fi
                        
                        if [ "${BUILD_ROOT}" != "${BUILD_ROOT_DFT}" ]; then
                            read -p  "Do you want to remove temporary build directory $BUILD_ROOT [Y/n]?" ans_r
                            if [[ "$ans_r" == "" || "$ans_r" == "y" || "$ans_r" == "Y" || "$ans_r" == "yes" ]]; then
                                $RM -rf $BUILD_ROOT
                            fi
                        fi    
                        
                     fi
                     
                     if make_install; then
                         echo
                         pass_echo "Configuring IPoIB, IBADM and OpenSM"
                         echo
                         pass_echo "You may do this stage later using option 4) in the main menu."
                         echo
                         echo " "
                         
                         read -p "Do you want to configure IPoIB, IBADM and OpenSM now? [Y/n]:" ans_conf
                         if [[ "$ans_conf" == "" || "$ans_conf" == "y" || "$ans_conf" == "Y" || "$ans_conf" == "yes" ]]; then
                            set_ip
                            set_configs
                         fi
                         
                         pass_echo "Installation finished successfully..."
                         
#                          if [ $NEED_REBOOT -ne 0 ]; then
#                              echo
#                              echo    "Please reboot the system after installation"
#                              echo
#                              read -p "Do you want to reboot now? [Y/n]:" ans_r
#                              if [[ "$ans_r" == "" || "$ans_r" == "y" || "$ans_r" == "Y" || "$ans_r" == "yes" ]]; then
#                                 $REBOOT
#                                 exit 0
#                              fi
#                          fi
                         getch
                     fi
                ;;
                3)
                    echo
                    showInstalled
                    echo
                    getch

                ;;
                4)
                    if ! isInstalled openib; then
                        echo
                        err_echo "You need first to install the InfiniBand Software"
                        echo
                        getch
                    else    
                        set_ip
                        set_configs
                    fi
                ;;
                5)
                    echo
                    uninstall
                    let NEED_REBOOT++
                ;;
                1)
                    view_readme
                ;;
                6)
                    ${CWD}/build.sh
                ;;    
                Q|q)
                    close_log    
                    exit 0
                ;;
                *)
                    return 1
                ;;
        esac
else

    check_space_req "$RUN_SPACE_REQ" "$STACK_PREFIX"

    # Check $CONFIG file
    if [ "${openib}${opensm}${mst}${ibadm}" != "yyyy" ]; then
        
        if [ "${openib}${opensm}${mst}${ibadm}" != "nnnn" ]; then
            echo
            echo "  openib (Infiniband HCA Driver), opensm (Infiniband Subnet Manager) , mst and ibadm are mandatory for"
            echo "  Infiniband operation"
            echo "  Please set \"openib=y\" , \"opensm=y\" , \"mst=y\" and \"ibadm=y\" in the $CONFIG file to Install Driver,"
            echo "  or set all packages to \"n\" to Uninstall all Infiniband Software"
            echo
            exit 5
        else    
            if [ "${mpi_ncsa}${mpi_osu}" != "nn" ]; then
                echo
                echo "  To Add packages set \"openib=y\" , \"opensm=y\" , \"mst=y\" and \"ibadm=y\" in the $CONFIG file"
                echo
                echo "  To remove packages set all variables to \"n\" in the $CONFIG file"
                echo
                exit 6
            fi
        fi
        
    fi

    if [ "${openib}${opensm}${mst}${ibadm}${mpi_ncsa}${mpi_osu}" == "nnnnnn" ]; then
        uninstall
    else

        # Check dependencies and print Warning messages
        local req_status=0
        
        IFS=';'
        for package in $REQUIRED_PACKAGES
        do
                pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                
                check_run_req $pack err
                let req_status=$req_status+$?
        done
        IFS=' '
        
        IFS=';'
        for package in $OPTIONAL_PACKAGES
        do
                pack=`echo $package | cut -d ':' -f 1 | tr -d [:space:]`
                check_run_req $pack warn
        done
        IFS=' '
        
        # Exit if there is missing required software for mandatory packages
        if [ $req_status -gt 0 ]; then
           exit 7
        fi   
        
        # Check if all required RPM packages exists
        # If not, run build.sh script with created configuration file
        if ! is_rpms; then
           ${CWD}/build.sh -c $CONFIG
           if [ $? -ne 0 ]; then
               exit 1
           fi
           # Reread config file (need if the config file was changed by build.sh )
           . $CONFIG
        fi
        make_install
        set_ip
        set_configs
    fi        


#     if [ $NEED_REBOOT -ne 0 ]; then
#         echo
#         echo    "Please reboot the system"
#         echo
#     fi
fi

return 0
}

open_log
while true
do
    main
    if [ $INTERACTIVE -eq 0 ]; then
        exit 0
    fi    
done    
