#!/bin/bash

RPM=/bin/rpm
RM=/bin/rm
NULL=/dev/null

# Default IBGD stack prefix
STACK_PREFIX=/usr/local/ibgd

ARCH=`uname -m`

OPENIB_NAME=openib
OPENSM_NAME=opensm
MST_NAME=mst
IBADM_NAME=ibadm
MPI_OSU_MPICH_NAME=mpich_mlx
MPI_NCSA_MPICH_NAME=mpich_mlx-ch_vmi
MPI_NCSA_VMI_NAME=vmi_mlx

# Execute command $@ and check exit status
ex()
{
echo Running $@
eval "$@"
if [ $? -ne 0 ]; then
     echo
     echo Failed executing \"$@\"
     echo
     exit 5
fi
}


uninstall()
{
local cnt=0
local OLD_PREFIX=""

if ( $RPM -q ${MPI_OSU_MPICH_NAME} > $NULL 2>&1 ); then
    ex "$RPM -e ${MPI_OSU_MPICH_NAME}"
    let cnt++
fi    

if ( $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 || $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 ); then
    $RPM -q ${MPI_NCSA_MPICH_NAME} > $NULL 2>&1 && ex "$RPM -e ${MPI_NCSA_MPICH_NAME}"
    $RPM -q ${MPI_NCSA_VMI_NAME} > $NULL 2>&1 && ex "$RPM -e ${MPI_NCSA_VMI_NAME}"
    let cnt++
fi    

if ( $RPM -q hmst-${ARCH} > $NULL 2>&1 ); then
    ex "$RPM -e hmst-${ARCH}"
    let cnt++
fi  

if ( $RPM -q ${IBADM_NAME} > $NULL 2>&1 ); then
    ex "$RPM -e ${IBADM_NAME}"
    let cnt++
fi    

if ( $RPM -q ${MST_NAME}-${ARCH} > $NULL 2>&1 ); then
    ex "$RPM -e ${MST_NAME}-${ARCH}"
    let cnt++
fi    

if ( $RPM -q ${OPENSM_NAME} > $NULL 2>&1 ); then
    ex "$RPM -e ${OPENSM_NAME}"
    let cnt++
fi    

if ( $RPM -q ibtsal > $NULL 2>&1 ); then
    ex "$RPM -e ibtsal"
    let cnt++
fi    

if ( $RPM -q thca-linux > $NULL 2>&1 ); then
    ex "$RPM -e thca-linux"
    let cnt++
fi    

if ( $RPM -q ${OPENIB_NAME} > $NULL 2>&1 ); then
    OLD_PREFIX=`$RPM -ql ${OPENIB_NAME} | grep "utils/create_devs" | sed -e 's/\/utils\/create_devs//'`
    ex "$RPM -e ${OPENIB_NAME}"
    let cnt++
elif [[ ! -z $MTHOME && -d $MTHOME ]]; then
    if [ -e $MTHOME/uninstall.sh ]; then
        echo
        echo "  An old version of OPENIB driver is detected and will be removed now"
        ex "echo y | env MTHOME=$MTHOME $MTHOME/uninstall.sh"
        let cnt++
    else
        echo
        echo "  An old version of OPENIB driver is detected in $MTHOME"
        echo "  Please remove it manually and unset MTHOME variable. Do logout and login to update environment variables"
        echo "  and then rerun INSTALL script"
        echo
        exit 3
    fi    
fi    

[ $cnt -eq 0 ] && echo && echo "No IBGD RPM packages found" && echo

local RC=0

# Remove links from /usr/bin to the scripts directory
if [ -d  ${STACK_PREFIX}/scripts ]; then
  cd ${STACK_PREFIX}/scripts
  for bin in *
  do
     [ "$bin" != "*" ] && rm -f /usr/bin/$bin
  done
  cd -
fi

if [ -d  ${OLD_PREFIX}/scripts ]; then
  cd ${OLD_PREFIX}/scripts
  for bin in *
  do
     [ "$bin" != "*" ] && rm -f /usr/bin/$bin
  done
  cd -
fi

[ -d /usr/local/ib_hpc ] && $RM -rf /usr/local/ib_hpc && let RC++
[ -d /usr/local/openib ] && $RM -rf /usr/local/openib && let RC++
[ -d /usr/local/ibgd ] && $RM -rf /usr/local/ibgd && let RC++
[ -d $STACK_PREFIX ] && ex "$RM -rf $STACK_PREFIX" && let RC++
[ -d $OLD_PREFIX ] && ex "$RM -rf $OLD_PREFIX" && let RC++

[ $RC -eq 0 ] && echo && echo "Please remove IBGD installation directory manually if exists" && echo

if [[ ! -d /etc/ibfw || ! -h /etc/ibfw ]]; then
    $RM -rf /etc/ibfw    
fi 
}

echo
echo "This program will uninstall all IB packages on your machine."
echo

read -p "Do you want to continue?[y/N]:" ans_r
if [[ "$ans_r" == "y" || "$ans_r" == "Y" || "$ans_r" == "yes" ]]; then
    uninstall
else    
    exit 1
fi




