#!/bin/bash 

# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#
# Description: RPM build script
#

build_root="/var/tmp/IBGD"
STACK_PREFIX=/usr/local/ibgd

usage()
{
cat << EOF

    `basename $0` [ -b <BUILD_ROOT> ] [ --prefix <Stack_Prefix> ]
                        
                The default BUILD_ROOT  is $build_root
                The default Stack Prefix is $STACK_PREFIX

EOF
}

while [ $# -gt 0 ]
do
    case $1 in
            --prefix)
                shift
                STACK_PREFIX=$1
            ;;
            -b)
                shift
                build_root=$1
            ;;
            *)
                usage
                exit 1
            ;;
    esac
    shift
done

BUILD_ENV="env STACK_PREFIX=$STACK_PREFIX build_root=$build_root"

cd ${0%*/*}

TMPFILE=/tmp/$$.tmp
SOURCE_DIR=`pwd`
KERNEL=`uname -r | sed -e "s/\-/\_/g"`
MPI_DIR=${PWD##*/}

NAME=vmi_mlx
VERSION=2.0.1
RELEASE=1

VMI_tgz=VMI20.tgz

build_arch=`rpm --showrc | grep -w "build arch" | cut -d : -f 2 | tr -d " "`

vmi_spec="vmi.spec"

if [ -d /usr/src/redhat ]; then
	RPM_DIR=/usr/src/redhat
elif [ -d /usr/src/packages ]; then
	RPM_DIR=/usr/src/packages
else
	echo Build rpm on this system is not supported...
	exit 1
fi

rm -f $RPM_DIR/SPECS/$vmi_spec 

rm -f $RPM_DIR/SOURCES/$VMI_tgz
 
cp -f $vmi_spec $RPM_DIR/SPECS

cp -f $SOURCE_DIR/$VMI_tgz $RPM_DIR/SOURCES/

if [ -f /etc/SuSE-release ]; then
   if [ `grep VERSION /etc/SuSE-release | cut -d = -f 2 | cut -d . -f 1 | tr -d [:space:]` -ge 9 ]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$vmi_spec # > /dev/null 2>&1
   else	
	$BUILD_ENV rpm -bb $RPM_DIR/SPECS/$vmi_spec # > /dev/null 2>&1
   fi
elif [[ -f /etc/redhat-release || -f /etc/rocks-release ]]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$vmi_spec # > /dev/null 2>&1
else
        echo Build rpm on this system is not supported...
        exit 1
fi

if [ $? != 0 ]; then
    echo RPM building failed...
    exit 1
fi 

rm -f $RPM_DIR/SOURCES/$VMI_tgz
rm -f $RPM_DIR/SPECS/$vmi_spec 

if [ ! -f $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm ] ; then
	echo RPM building failed...
	exit 1
else
	echo RPM: $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm 
fi

exit 0

