#!/bin/bash 

# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#
# Description: RPM build script
#

build_root="/var/tmp/IBGD"
STACK_PREFIX=/usr/local/ibgd

usage()
{
cat << EOF

    `basename $0` [ -b <BUILD_ROOT> ] [ --prefix <Stack_Prefix> ]
                        
                The default BUILD_ROOT  is $build_root
                The default Stack Prefix is $STACK_PREFIX

EOF
}

while [ $# -gt 0 ]
do
    case $1 in
            --prefix)
                shift
                STACK_PREFIX=$1
            ;;
            -b)
                shift
                build_root=$1
            ;;
            *)
                usage
                exit 1
            ;;
    esac            
    shift
done

BUILD_ENV="env STACK_PREFIX=$STACK_PREFIX build_root=$build_root"

cd ${0%*/*}

TMPFILE=/tmp/$$.tmp
SOURCE_DIR=`pwd`
KERNEL=`uname -r | sed -e "s/\-/\_/g"`
MPI_DIR=${PWD##*/}

NAME=mpich_mlx
VERSION=0.9.4

SOURCE0=mvapich-0.9.4.tar.gz
SOURCE1=mvapich-0.9.4_complib.patch.gz
SOURCE2=mvapich-0.9.4_patch_101.gz
SOURCE3=mvapich-0.9.4_patch_102.gz
SOURCE4=mvapich-0.9.4_patch_103.gz
SOURCE5=mvapich-0.9.4_patch_104.gz
SOURCE6=mvapich-0.9.4_patch_106.gz
SOURCE7=mvapich-0.9.4_patch_107.gz
SOURCE8=mvapich-0.9.4_patch_108.gz
SOURCE9=mvapich-0.9.4_mcst.patch.gz
SOURCE10=mvapich-0.9.4_np_param.patch.gz
SOURCE11=mvapich-0.9.4_mcst_leave.patch.gz
SOURCE12=mvapich-0.9.4_SG_receive.patch.gz
SOURCE13=PMB2.2.1.tar.gz
SOURCE14=presta1.2.tgz
SOURCE15=osu-tests.tar.gz

build_arch=`rpm --showrc | grep -w "build arch" | cut -d : -f 2 | tr -d " "`

mpich_spec="mpich-osu.spec"

if [ -d /usr/src/redhat ]; then
	RPM_DIR=/usr/src/redhat
elif [ -d /usr/src/packages ]; then
	RPM_DIR=/usr/src/packages
else
	echo Build rpm on this system is not supported...
	exit 1
fi

rm -f $RPM_DIR/SPECS/$mpich_spec

rm -f $RPM_DIR/SOURCES/$SOURCE0
rm -f $RPM_DIR/SOURCES/$SOURCE1
rm -f $RPM_DIR/SOURCES/$SOURCE2
rm -f $RPM_DIR/SOURCES/$SOURCE3
rm -f $RPM_DIR/SOURCES/$SOURCE4
rm -f $RPM_DIR/SOURCES/$SOURCE5
rm -f $RPM_DIR/SOURCES/$SOURCE6
rm -f $RPM_DIR/SOURCES/$SOURCE7
rm -f $RPM_DIR/SOURCES/$SOURCE8
rm -f $RPM_DIR/SOURCES/$SOURCE9
rm -f $RPM_DIR/SOURCES/$SOURCE10
rm -f $RPM_DIR/SOURCES/$SOURCE11
rm -f $RPM_DIR/SOURCES/$SOURCE12
rm -f $RPM_DIR/SOURCES/$SOURCE13
rm -f $RPM_DIR/SOURCES/$SOURCE14
rm -f $RPM_DIR/SOURCES/$SOURCE15
 
cp -f $mpich_spec $RPM_DIR/SPECS

cp -f $SOURCE_DIR/$SOURCE0 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE1 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE2 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE3 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE4 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE5 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE6 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE7 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE8 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE9 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE10 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE11 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE12 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE13 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE14 $RPM_DIR/SOURCES/
cp -f $SOURCE_DIR/$SOURCE15 $RPM_DIR/SOURCES/

if [ -f /etc/SuSE-release ]; then
   if [ `grep VERSION /etc/SuSE-release | cut -d = -f 2 | cut -d . -f 1 | tr -d [:space:]` -ge 9 ]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$mpich_spec # > /dev/null 2>&1
   else	
	$BUILD_ENV rpm -bb $RPM_DIR/SPECS/$mpich_spec # > /dev/null 2>&1
   fi
elif [[ -f /etc/redhat-release || -f /etc/rocks-release ]]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$mpich_spec # > /dev/null 2>&1
else
        echo Build rpm on this system is not supported...
        exit 1
fi

if [ $? != 0 ]; then
    echo RPM building failed...
    exit 1
fi 



rm -f $RPM_DIR/SOURCES/$SOURCE0
rm -f $RPM_DIR/SOURCES/$SOURCE1
rm -f $RPM_DIR/SOURCES/$SOURCE2
rm -f $RPM_DIR/SOURCES/$SOURCE3
rm -f $RPM_DIR/SOURCES/$SOURCE4
rm -f $RPM_DIR/SOURCES/$SOURCE5
rm -f $RPM_DIR/SOURCES/$SOURCE6
rm -f $RPM_DIR/SOURCES/$SOURCE7
rm -f $RPM_DIR/SOURCES/$SOURCE8
rm -f $RPM_DIR/SOURCES/$SOURCE9
rm -f $RPM_DIR/SOURCES/$SOURCE10
rm -f $RPM_DIR/SOURCES/$SOURCE11
rm -f $RPM_DIR/SOURCES/$SOURCE12
rm -f $RPM_DIR/SOURCES/$SOURCE13
rm -f $RPM_DIR/SOURCES/$SOURCE14
rm -f $RPM_DIR/SOURCES/$SOURCE15
rm -f $RPM_DIR/SPECS/$mpich_spec 


if [ ! -f $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm ] ; then
	echo RPM building failed...
	exit 1
else
	echo RPM: $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm 
fi

exit 0

