#!/bin/bash 
#
# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#

#cd ${0%*/*}
# pointing to the dir where this install script resides
PACKAGE_ORIG_DIR=`cd ${0%*/*};pwd`

# we modify the srcs so we need to 
PACKAGE_DIR=/tmp/ibadm_install_tmp
if [ -d $PACKAGE_DIR ]; then
    rm -rf $PACKAGE_DIR
fi
mkdir -p $PACKAGE_DIR

# copy over the original dir
cp -ap $PACKAGE_ORIG_DIR/* $PACKAGE_DIR/

# go there
cd $PACKAGE_DIR

IBADM_PATCH_COOKY="Added by IBADM install.sh"

########################################################################
#
# FUNCTIONS:
#

#Usage: clean_file <file name> . 
#Cleans all previously pathched by install.sh lines 
function clean_file() {
   if ! [ -a $1 ]; then touch $1; fi
   grep -v "$IBADM_PATCH_COOKY" $1 > /tmp/tmp.file.ibadm
   mv -f /tmp/tmp.file.ibadm $1
   rm -f /tmp/tmp.file.ibadm
}

#Usage: set_env_csh <env file name> <env name> <env val>
function set_env_csh() {
   echo setenv $2 $3 \# $IBADM_PATCH_COOKY >> $1   
}

#Usage: set_env_bash <env file name> <env name> <env val>
function set_env_bash() {
   echo export $2=$3 \# $IBADM_PATCH_COOKY >> $1   
}

#Usage: set_env <env file name> <shell type: csh or bash>
function set_env() {
   clean_file $1
   case $2 in
      "csh")
         set_env_csh $1 PATH $CONFIG_ROOT/bin:\$PATH
#         set_env_csh $1 TCLLIBPATH $IBADMHOME/lib
        ;;
      "bash")
         set_env_bash $1 PATH $CONFIG_ROOT/bin:\$PATH
#         set_env_bash $1 TCLLIBPATH $IBADMHOME/lib
        ;;
      *)   
   esac  
}

#Usage: check_file <file name>
function check_file() {
   if [ ! -f $1 ]; then                                               
      touch $1
      echo "Added $1 into your linux revision."
      echo "Take care to include its activation on your login." 
   fi   
}

# Heruristically try and detect if the ibgd or vapi stack are installed.
# if they are set the global STACK variable accordingly.
# if neither is found - set it to "unknown"
#Usage auto_detect_stack
function  auto_detect_stack() {
    # we give priority to ibgd installation (over vapi)
    if test -f /usr/local/ibgd/driver/infinihost/include/vapi.h; then
        STACK=ibgd
    elif test -f /usr/include/vapi.h; then
        STACK=vapi4
    elif test -f /usr/mellanox/include/vapi.h; then
        STACK=vapi3        
    else
        STACK=unknown
    fi
}

#Usage: set_stack <stack> 
function set_stack() {
    local stack="$1"
    local ib_prefix
    local osm_prefix

    case $stack in
       "openib" | "ibgd")
            if test -z $BUILD_ROOT; then
                ib_prefix=/usr/local/ibgd/driver/infinihost
                osm_prefix=/usr/local/ibgd/apps/osm
            else
                ib_prefix="${BUILD_ROOT}${STACK_SOURCE}/driver/infinihost"
                osm_prefix="${BUILD_ROOT}${STACK_SOURCE}/apps/osm"
            fi
            ;;
       "vapi3")
            ib_prefix=" /usr/mellanox/"
            osm_prefix="/usr/mellanox/"
            ;;
       "vapi4")
            ib_prefix=" /usr/"
            osm_prefix="/usr/mellanox/"
            ;;
       *)
	    echo "-E- Invalid stack type - $stack"
	    exit 1
	    ;;
    esac
    
    # do not override pre-exsiting prefix settings
    if test -z $IB_PREFIX; then 
        export IB_PREFIX=$ib_prefix
    else
        echo "Using pre-defined IB_PREFIX=$IB_PREFIX"
    fi
    if test -z $OSM_PREFIX; then 
        export OSM_PREFIX=$osm_prefix
    else
        echo "Using pre-defined OSM_PREFIX=$OSM_PREFIX"    
    fi
}

function cleanup_ibadm_files() {
    # Clean old distribution
    binApps="ibadm ibis ibns ibbs ibburn ibfwmgr ibtopogen ibmon ibls ibcert obbs-pci 
            unify_image_section t2a mic aimage ibdmtr ibdmchk ibdmsim 
            ibdmsh ibcon ibnlparse"

    echo " Removing Executables from : .......... $CONFIG_ROOT/bin." 
    for f in $binApps; do 
        rm -f ${CONFIG_ROOT}/bin/$f 2&>1 > /dev/null; 
        if [ $? == 0 ]; then
            echo "Removed : ${CONFIG_ROOT}/bin/$f" >> $CFGLOG
        fi
    done
   
    echo " Removing Include Files from : ........ $CONFIG_ROOT/include."
    rm -rf ${CONFIG_ROOT}/include/ibdm 2&>1 > /dev/null
    if [ $? == 0 ]; then
        echo "Removed : ${CONFIG_ROOT}/include/ibadm" >> $CFGLOG
    fi
    
    echo " Removing Old IBADM Distrib Libs from : $CONFIG_ROOT/lib."
    libs="ibbbm1.0 ibconf1.0 ibcr1.0 ibdm1.0 ibis1.0 ibpm1.0 ibsac1.0 
          g_file1.0 g_puts1.0 ibadmConn1.0 inifile1.0 
          libibdm.a libibdm.la libibdm.so libibdm.so.1 
          libibdm.so.1.1.1 libibdmcom.a libibdmcom.la 
          libibdmcom.so libibdmcom.so.1 libibdmcom.so.1.1.1"
    for f in $libs; do 
        rm -rf ${CONFIG_ROOT}/lib/$f 2&>1 > /dev/null; 
        if [ $? == 0 ]; then
            echo "Removed : ${CONFIG_ROOT}/lib/$f" >> $CFGLOG
        fi
    done
    echo " Removing IBADM Libs from : ........... $CONFIG_ROOT/lib/ibadm."
    rm -rf ${CONFIG_ROOT}/lib/ibadm 2&>1 > /dev/null
    if [ $? == 0 ]; then
        echo "Removed : ${CONFIG_ROOT}/lib/ibadm" >> $CFGLOG
    fi

    echo " Removing IBADM Man Pages from : ...... /usr/share/man/man1."
    mans="ibadm ibcon ibmon ibls ibadm.conf ibfwmgr ibtopogen ibcert"
    for f in $mans; do 
        rm -rf /usr/share/man/man1/$f.1.* 2&>1 > /dev/null; 
        if [ $? == 0 ]; then
            echo "Removed : " /usr/share/man/man1/$f.1.* >> $CFGLOG
        fi
    done
}

#Usage: create_config_file 
#create the /etc/ibadm.conf
function create_config_file() {
	IP_ADD=`/sbin/ifconfig | grep "inet addr" | grep "Bcast" | awk '{split($2,a,":");print a[2]}'`
	if [ "$IP_ADD" == "" ] ; then
		exit 1
	fi
   # we do not override existing file - just copy new one
   if test -f /etc/ibadm.conf; then 
        cp $PACKAGE_DIR/libs/ibconf1.0/ibadm.conf /etc/ibadm.conf.installed
   else 
        cp $PACKAGE_DIR/libs/ibconf1.0/ibadm.conf /etc/ibadm.conf
   fi
}

#Report: if config failed
function config_failed() {
	echo "Config failed ! (see $CFGLOG for details)"
	exit 1
}

#Report: if make failed
function make_failed() {
	echo "Make failed ! (see $MAKELOG for details)"
	exit 1
}

#Report: if tcl failed
function tcl_failed() {
	echo "Making Internal Tcl failed ! (see $TCLMAKELOG for details)"
	exit 1
}

#Check if MST libmtcr.a is pre-installed - if not give an error and exit
function check_mst() {
    if test -z $MST_HOME; then 
        export MST_HOME=/usr/mst
    fi

    if test ! -f $MST_HOME/lib/libmtcr.a; then
        echo "IBADM Depends on pre-installed MST. Fail to find $MST_HOME/lib/libmtcr.a"
        exit 1
    fi
}

########################################################################

PLATF=`uname -m`

case $PLATF in
    "i686")
         MY_EXT="x86"
         EXPECTED_MAKEINSTALLLOG_SIZE=42796
         ;;
    "ia64")
         MY_EXT="ia64"
         EXPECTED_MAKEINSTALLLOG_SIZE=41868
         tcl_flag64=--enable-64bit
         ;;
    "x86_64")
         MY_EXT="x86_64"
         EXPECTED_MAKEINSTALLLOG_SIZE=42817
         ;;
    *)
         echo "Unsupported platform. IBADM Currently supports only x86, ia64, x86_64 platforms"
         exit 1
esac

# Initialize default before parsing parameters
STACK_SOURCE=/usr/local/ibgd
CONFIG_ROOT=/usr
INSTALL_ROOT=/usr/mellanox/ibadm
BUILD_ROOT=
INSTALL_LIB=/usr/mellanox
NO_CFG=0
BUILD_ONLY=0
NO_BAR=0
DIST=0
LOCAL_NODE=0
INSTALL_GZLIB=0

# Set default stack paths
auto_detect_stack

# parse parameters
while [ "$1" ]; do
#  echo "Current parsed param is : $1"
  case $1 in
    "-ss") 
          STACK_SOURCE=$2
          shift
          ;;
    "--prefix") 
          CONFIG_ROOT=$2
          shift
          ;;
    "--build_root") 
          BUILD_ROOT=$2
          shift
          ;;
    "--batch") 
          NO_BAR=1
          echo "<<<<<<<< NO PROGRESS BAR   >>>>>>>>>>"
          ;;
    "--build_only") 
          BUILD_ONLY=1
          echo "<<<<<<<< BUILD_ONLY   >>>>>>>>>>"
          ;;
    "-d") 
          INSTALL_ROOT=$2
          shift
          ;;
    "-nc")
          NO_CFG=1
          echo "<<<<<<<< NO CONFIG CREATION >>>>>>>>>>"
          ;;
    "--dist")
          DIST=1
          echo "<<<<<<<< DISTRIBUTION MODE >>>>>>>>>>"
          ;;
    "-b") 
          STACK=$2
          shift
          ;;

    "--local")
          LOCAL_NODE=1
          shift
          ;;
    "--i2c")
          INSTALL_GZLIB=1
          shift
          ;;
    *)
     echo "Usage: $0 [--local][--batch][--dist][--build_root <bld-root-dir>]"
     echo "          [--prefix <install-dir>][-d <bld-dir>][-nc]"
     echo "          [-b <stack type>][--build_only][--i2c]"
     echo "Options:"
     echo "   --local : install 'local node' only software for device burning"
     echo "   --dist : cause the installation to create a distribution tar file and make tcl code standalone."
     echo "   --prefix <dir> : place bin/lib/include into <dir>"
     echo "   -d <dir> : place the build tree of IBADM into <dir>" 
     echo "   -nc option : do not create /etc/ibadm.conf"
     echo "   -b <ibgd> : the standard distribution we install under (default ibgd)"
     echo "   -ss <dir> : base for stack files to work with - valid only when -b is openib (default /usr/local/openib)"
     echo "   --batch option : do not use progress bar"
     echo "   --build_only option : do not update envieronment parameters"
     echo "   --build_root <dir> : use <dir> as addition to the prefix"
     echo "   --i2c : install the agent for i2c control over remote systems"
      
     exit 1
  esac
  shift
done

# Now after the user selected the stack - use it to set the defaults
# For local node installation - stack doesn't matter.
if [ $LOCAL_NODE -eq 0 ]; then
  set_stack $STACK
fi

# take the src BUILD_ID
BLD_ID="<unknown>"
if test -e ${PACKAGE_DIR}/BUILD_ID ; then
  BLD_ID=`cat ${PACKAGE_DIR}/BUILD_ID`
fi

KERNEL_VER=`uname -r`

#if [[ `uname -m` == "x86_64" ]]; then
#   tar_file=ibadm-x86_64.tgz
#else
#if [[ `uname -m` == "ia64" ]]; then
#   tar_file=ibadm-ia64.tgz
#else
   tar_file=ibadm.tgz
#fi
#fi

if test ! -f $tar_file; then
    echo " Fail to find matching tar file for the current platform:$tar_file"
    exit 1
fi

cd $PACKAGE_DIR 
tar -zxf $tar_file
find . -exec touch {} \;
#cd ibdm
#./config/bootstrap 2>&1 | cat > /dev/null
#echo ``

# Make sure the build root is available to the lower levels
export BUILD_ROOT
export LOCAL_NODE

# We also use the BLD_ID 
BLD_VER=$BLD_ID
export BLD_VER

CFGLOG=/tmp/IBADM.config.log.$$
rm -f /tmp/IBADM.config.log.* 2&>1 > /dev/null
echo "IBADM-$MY_EXT \($BLD_ID\) configuration as `date`." >| $CFGLOG
echo "Modules configuration log file:" >| $CFGLOG

MAKELOG=/tmp/IBADM.make.log.$$
rm -f /tmp/IBADM.make.log.* 2&>1 > /dev/null
echo "IBADM-$MY_EXT \($BLD_ID\) installation at `date`." >| $MAKELOG
echo "Modules making log file:" >| $MAKELOG

MSTMAKELOG=/tmp/IBADM.mst.log.$$
rm -f /tmp/IBADM.mst.log.* 2&>1 > /dev/null

TCLMAKELOG=/tmp/IBADM.tcl.log.$$
rm -f /tmp/IBADM.tcl.log.* 2&>1 > /dev/null

export IBADMHOME=$INSTALL_ROOT

echo IBADM installation script - IBADM Build: $BLD_ID
echo Copyright \(C\) June 2002, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
echo Use of software subject to the terms and conditions detailed in the 
echo file \"LICENSE.txt\".
echo " "

if [ $UID != 0 ]; then
  echo You must be root to install IBADM
  rm -rf $PACKAGE_DIR
  exit 1
fi
umask 022   # assure readibility to all users

if test $LOCAL_NODE = 0; then

    # Chech for the vital files under IB_PREFIX
    if test ! -r $IB_PREFIX/include/vapi.h; then 
        echo "-------------------------------------------------------------" 
        echo "-E- IB_PREFIX does not point to a valid installation."
        echo "    Fail to find vapi.h at: \$IB_PREFIX/include."
        echo "    Current path is: $IB_PREFIX/include"
    fi

    #    echo "OSM_PREFIX used is -- "$OSM_PREFIX
    #    echo "IB_PREFIX used is -- "$IB_PREFIX
    # Chech for the vital files under OSM_PREFIX
    if test ! -r $OSM_PREFIX/include/opensm/osm_build_id.h; then 
        echo "-------------------------------------------------------------" 
        echo "-E- OSM_PREFIX does not point to a valid OpenSM installation."
        echo "    Fail to find osm_build_id.h: \$OSM_PREFIX/include/opensm."
        echo "    Current path is: $OSM_PREFIX/include/opensm"
    fi
else
    echo ">>>>> Installing Single Node Tools Only <<<<< "
    echo " "
fi
# Not local node

# Check for previous installations
if [ -n $IBADMHOME ] ; then
  if [ -d $IBADMHOME ] ; then
    OLD_BLD_ID="<unknown>"
    if [ -f $IBADMHOME/BUILD_ID ]; then
        OLD_BLD_ID=`cat $IBADMHOME/BUILD_ID`
    fi
    echo "Found traces of another Mellanox software installation at $IBADMHOME."
    echo "Current installed IBADM Build ID is $OLD_BLD_ID"
    echo "This installation IBADM Build ID is $BLD_ID"
    echo -n "Remove currently installed components (rm -rf $IBADMHOME) (y/n) [n] ? "
    read force 
    if [ "$force" != "y" ] && [ "$force" != "yes" ] && [ "$force" != "Y" ] && [ "$force" != "YES" ] ; then
       rm -rf $PACKAGE_DIR
       exit 1
    else
       # Clean old distribution
       rm -rf $IBADMHOME
       if [ "$NO_CFG" == "0" ] ; then
            if [ -f /etc/ibadm.conf ]; then
                cp -f /etc/ibadm.conf /etc/ibadm1.conf
            fi
       fi
       if [ $BUILD_ONLY == 0 ]; then 
           cleanup_ibadm_files
       fi
    fi
  fi
fi

mkdir -p $IBADMHOME
cp ${PACKAGE_DIR}/BUILD_ID ${IBADMHOME}/BUILD_ID
cp ${PACKAGE_DIR}/uninstall.sh ${IBADMHOME}/
cp ${PACKAGE_DIR}/LICENSE.txt ${IBADMHOME}/
    
echo ""
echo ""
if test ! -z $BUILD_ROOT; then
FINAL_PREFIX=`echo $CONFIG_ROOT | sed 's='$BUILD_ROOT'=/='`
else
FINAL_PREFIX=$CONFIG_ROOT
fi
echo "This installation installs the IBADM components into $FINAL_PREFIX"
cd $IBADMHOME

# Install MST
if test -f ${PACKAGE_DIR}/mst-`uname -m`-*.tgz; then
    echo " Installing MST ..."
    tar xfz ${PACKAGE_DIR}/mst-`uname -m`-*.tgz
    ./mst-`uname -m`*/mst_install > $MSTMAKELOG 2&>1 <<EOF


EOF
    if test $? != 0; then
        echo "MST Installation failed! See $MSTMAKELOG for details"
        exit 1
    fi
else
    echo "No MST for machine:`uname -m` ?"
fi

# check if MST libmtcr is available
check_mst

if test $INSTALL_GZLIB != 0; then 
echo " Installing I2C Agent and driver ..."
tar xfz ${PACKAGE_DIR}/gz_lib.tgz
gz_lib_*/install.sh  >> $MSTMAKELOG 2&>1 <<EOF
y

EOF

fi

echo " Building internal Tcl 8.4 installation ..."
cd $IBADMHOME
TCL_PREFIX=$CONFIG_ROOT/lib/ibadm/tcl
tar xfz ${PACKAGE_DIR}/tcl.tar.gz >> $TCLMAKELOG 2>&1
find tcl8.4.9 -exec touch {} \;
cd tcl*/unix 
# NOTE we used TCL shared lib to avoid issues with loading libs (on IA64)
./configure --prefix=$TCL_PREFIX --enable-threads $tcl_flag64 --enable-debug >> $TCLMAKELOG 2>&1
make>> $TCLMAKELOG 2>&1
if [ $? != 0 ]; then tcl_failed ; fi
make install>> $TCLMAKELOG 2>&1
if [ $? != 0 ]; then tcl_failed ; fi
# we will use this tclsh in the underlying config and build ...
export TCLSH=$TCL_PREFIX/bin/tclsh8.4

# Now we make the thread package...
cd $IBADMHOME
tar xfz ${PACKAGE_DIR}/thread.tar.gz >> $TCLMAKELOG 2>&1
find thread -exec touch {} \;
cd thread
./configure --prefix=$TCL_PREFIX --enable-threads --with-tclsh=$TCLSH $tcl_flag64 --enable-debug >> $TCLMAKELOG 2>&1
make>> $TCLMAKELOG 2>&1
if [ $? != 0 ]; then tcl_failed ; fi
make install>> $TCLMAKELOG 2>&1
if [ $? != 0 ]; then tcl_failed ; fi

# we might want to install daemonize:
echo " Building daemonize ..."
cd $IBADMHOME
tar xfz ${PACKAGE_DIR}/daemonize-1.4.tgz >> $TCLMAKELOG 2>&1
cd daemonize-1.4
./configure --prefix=$CONFIG_ROOT >> $TCLMAKELOG 2>&1
make >> $TCLMAKELOG 2>&1
make install >> $TCLMAKELOG 2>&1

cd $IBADMHOME
export PATH=$PATH:${PACKAGE_DIR}
echo " Configuring $IBADMHOME directory ..."
${PACKAGE_DIR}/configure --prefix ${CONFIG_ROOT} >> $CFGLOG 2>&1 &
config_pid=$!
wait $config_pid >/dev/null 2>&1
if [ $? != 0 ]; then config_failed ; fi
echo " Building all packages (this will take a few minutes) ... "
make install>> $MAKELOG 2>&1 &
make_pid=$!

if [ "$NO_BAR" == "0" ] ; then
	$PACKAGE_DIR/fprogbar.sh $MAKELOG $EXPECTED_MAKEINSTALLLOG_SIZE $make_pid
fi

wait $make_pid >/dev/null 2>&1
if [ $? != 0 ]; then make_failed ; fi

# Copy the BUILD_ID to the IBADMHOME (where we leave the sources etc)
cp ${PACKAGE_DIR}/BUILD_ID ${IBADMHOME}/BUILD_ID

# Prepare default ibadm.conf 
if test $NO_CFG = 0 && test $LOCAL_NODE = 0; then
    echo " Creating config file : /etc/ibadm.conf"
    create_config_file
fi
echo " Executables were placed in : $CONFIG_ROOT/bin"

# Copy docs
echo " Copying docs .."
cp ${PACKAGE_DIR}/README ${IBADMHOME}

#####################Update environment#############################
# we only need to set env if the prefix is not /usr and build_only option not used:
if [ $BUILD_ONLY == 0 ]; then 
    if [ "$CONFIG_ROOT" != "/usr" ]; then 
        echo "Setting up environment ..."

        #add environment to /etc/csh.cshrc
        check_file /etc/csh.cshrc csh
        set_env /etc/csh.cshrc csh
        set_env /etc/csh.cshrc.local csh

        #add environment to /etc/bashrc
        check_file /etc/bashrc bash
        set_env /etc/bashrc bash
        check_file /etc/profile bash
        set_env /etc/profile bash
        set_env /etc/bash.bashrc.local bash

        if test $LOCAL_NODE = 0; then
            ln -fs $CONFIG_ROOT/bin/ibadm  /usr/bin/ibadm
            ln -fs $CONFIG_ROOT/bin/ibbs  /usr/bin/ibbs
            ln -fs $CONFIG_ROOT/bin/ibcon  /usr/bin/ibcon
            ln -fs $CONFIG_ROOT/bin/ibfwmgr  /usr/bin/ibfwmgr
            ln -fs $CONFIG_ROOT/bin/ibls  /usr/bin/ibls
            ln -fs $CONFIG_ROOT/bin/ibmon  /usr/bin/ibmon
            ln -fs $CONFIG_ROOT/bin/ibns  /usr/bin/ibns
            ln -fs $CONFIG_ROOT/bin/ibcert  /usr/bin/ibcert
            ln -fs $CONFIG_ROOT/bin/libibis.1.0.so  /usr/bin/libibis.1.0.so
        fi
        ln -fs $CONFIG_ROOT/bin/ibdmchk  /usr/bin/ibdmchk
        ln -fs $CONFIG_ROOT/bin/ibdmsh  /usr/bin/ibdmsh
        ln -fs $CONFIG_ROOT/bin/ibdmtr  /usr/bin/ibdmtr
        ln -fs $CONFIG_ROOT/bin/aimage  /usr/bin/aimage
        ln -fs $CONFIG_ROOT/bin/ibburn  /usr/bin/ibburn
        ln -fs $CONFIG_ROOT/bin/mic  /usr/bin/mic
        ln -fs $CONFIG_ROOT/bin/t2a  /usr/bin/t2a
        ln -fs $CONFIG_ROOT/bin/unify_image_section  /usr/bin/unify_image_section
        # daemonize build is optional based on missing one on the machine ...
        if test -f $CONFIG_ROOT/bin/daemonize; then
            ln -fs $CONFIG_ROOT/bin/daemonize  /usr/bin/daemonize
        fi 

        echo ${CONFIG_ROOT}/lib >> /etc/ld.so.conf
        /sbin/ldconfig
        echo "Environment files have been updated"
    fi 
    # end of copy of executables as we did not install to /usr

    # do other copies like docs etc
    if test $LOCAL_NODE = 0; then
        # Copy ibadm.topo file with 2 examples in it
        echo " Copying ibadm.topo file to : /etc/ibadm.topo"
        if [ -f /etc/ibadm.topo ]; then
            echo " Saving new reference ibadm.topo file to : /etc/ibadm.topo.new"
            cp ${PACKAGE_DIR}/ibadm.topo /etc/ibadm.topo.new
        else
            cp ${PACKAGE_DIR}/ibadm.topo /etc/ibadm.topo
        fi

        # Copy man pages to it's location
        echo " Copying man pages files to : /usr/share/man/man1/"
        cp ${PACKAGE_DIR}/man/ibadm.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibcon.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibmon.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibcert.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibls.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibadm.conf.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibfwmgr.1.gz /usr/share/man/man1/
        cp ${PACKAGE_DIR}/man/ibtopogen.1.gz /usr/share/man/man1/
    fi
    cp ${PACKAGE_DIR}/man/mlxburn.1.gz /usr/share/man/man1/
fi

# cleanup
rm -rf $PACKAGE_DIR

echo IBADM installation done.
echo "  "
exit 0
