#!/bin/bash 
#
# A script to install OpenIB user-space
#

function usage {
    echo 'install.sh [--batch] [--help] [--prefix PREFIX] [--tmpdir DIR] --clean '
    echo '           [--nosu] [-k|--ksrc DIR]'
    exit 0
}
# Execute command w/ echo and exit if it fail
ex()
{
    if ! "$@"; then
        echo "-E- $@"
        error "aborting ..."        
        exit 1
    fi
}

# Issue the error message given by $1 and exit with a non-zero
# exit code.

error() {
    echo "user-install.sh: *** $1" 1>&2
}


# Find the directory where this script resides
installdir=`cd ${0%*/*};pwd`
prog=$0
tmpdir=/tmp/ibgd-user
prefix=/usr/local/ibgd
clean=no
batch=no
nosu=no
SET_ENV=1
vapi_ver=3.2

KVERSION=$(uname -r)
KVERSION_TWO_DIGITS=2$(echo ${KVERSION} | cut -d"." -f2)

# Handle the case there is no makedepend...
export PATH=${PATH}:${installdir}

while [ "$1" ]; do
 	case "$1" in
		-t|--tmpdir)
                        tmpdir=$2
                        shift 2
                        ;;
                -k|--ksrc)
                        KSRC=$2
                        shift 2
                        ;;
                --vapi)
                        vapi_ver=$2
                        shift 2
                        ;;
		-p|--prefix)
                        prefix=$2
                        shift 2
                        ;;
		-h|--help)
                        usage
                        shift
                        ;;
		-c|--clean)
                        clean=yes
                        shift
                        ;;
		-b|--batch)
                        batch=yes
                        shift
                        ;;
                --build_only)
                        SET_ENV=0
                        shift
                        ;;        
		--nosu)
                        nosu=yes
                        shift
                        ;;
 		--)
                        shift
                        break
                        ;;
 		*)
                        echo "Wrong parameter error!"
                        usage
                        exit 1
                        ;;
   esac
done

KSRC=${KSRC:-/lib/modules/`uname -r`/build}
KERNEL_TREE_ROOT=${KSRC%*/*}
#Special case for SuSE9.1 and SlES9.0 build tree
if [ -d ${KERNEL_TREE_ROOT}/source/ ]; then
   KSRC=${KERNEL_TREE_ROOT}/source
fi
echo "Installing IBGD userspace into ${prefix}"

if [ "$nosu" == "no" ]; then
    if [ $UID -ne 0 ]; then
        echo You must be root to install IBGD
        exit 1
    fi
fi


# make sure we have the tmpdir
rm -rf ${tmpdir}
mkdir -p ${tmpdir}

# make sure we have the prefix dir is empty
if [ -e ${prefix} ]; then
        if [ "$batch" == "no" ]; then
            echo "${prefix} already exists!"
            echo -n "Remove currently installed components (rm -rf ${prefix}) (y/n) [y] ? "
            read force
        else
            force="yes"
        fi
        if [ "x$force" == "xy" ] \
                 || [ "x$force" == "xyes" ] \
                 || [ "x$force" == "xY" ] \
                 || [ "x$force" == "xYES" ] \
                 || [ "x$force" == "x" ]  ; then
           echo "Clean old distribution at ${prefix}"
           rm -rf ${prefix}
        else
           echo "Aborting installation"
           exit 1
        fi

fi

mkdir -p ${prefix}/bin

##################################################################
###     user-mellanox
##################################################################

# Open the tar file into the tmp dir:
cd ${tmpdir}
ex tar -zxf ${installdir}/user-mellanox-hca.tgz

buildid=`cat ${installdir}/BUILD_ID`

# we rely on the fact we have opened the tar file so 
# have a local base dir:
if [ ! -d user-mellanox-hca ]; then 
	 echo "Expected to find a sub-directory named 'user-mellanox-hca' in current dir"
 	 echo "TAR file probably was not opened locally!"
	 exit
fi

mkdir -p ${prefix}/src
ex cp -rp ${tmpdir}/user-mellanox-hca/vapi-${vapi_ver} ${prefix}/src/user-mellanox-hca

export MAKELOG=make.log
export EXPECTED_MAKELOG_SIZE=52000

cd ${tmpdir}/user-mellanox-hca/vapi-${vapi_ver}
/bin/rm -f $MAKELOG
echo "Making IBGD mellanox-hca (user) in ${tmpdir} ..."
make PREFIX=${prefix}/driver/infinihost VAPI_KERNEL_SRC_DIR=${KSRC}/drivers/infiniband/hw/mellanox-hca/vapi-${vapi_ver} MT_INSTALL_PREFIX=${prefix}/driver/infinihost install > $MAKELOG 2>&1  &
make_pid=$!
if [ "$batch" == "no" ]; then
  ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
fi
wait $make_pid >/dev/null 2>&1 

if [ $? -ne 0 ]; then 
	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
	 exit 1
fi


echo "Installation of IBGD mellanox-hca (user) completed successfully"



##############################################################
###     libsdp
##############################################################


# Open the tar file into the tmp dir:
cd ${tmpdir}
ex tar -zxf ${installdir}/libsdp.tgz

# we rely on the fact we have opened the tar file so 
# have a local base dir:
if [ ! -d libsdp ]; then 
	 echo "Expected to find a sub-directory named 'libsdp' in current dir"
 	 echo "TAR file probably was not opened locally!"
	 exit
fi

ex cp -rp ${tmpdir}/libsdp ${prefix}/src/

export MAKELOG=make-libsdp.log
export EXPECTED_MAKELOG_SIZE=7600

cd ${tmpdir}/libsdp
/bin/rm -f $MAKELOG


if [ "`uname -m`" == "x86_64"  ]; then
  echo "Making IBGD libsdp in ${tmpdir} (32 bit version) ..."
  export CFLAGS=-m32
  export CXXFLAGS=-m32
  export FFLAGS=-m32
  export LDFLAGS="-m32 -Xcompiler -m32"
  ./configure --prefix=${prefix} >> $MAKELOG 2>&1
  if [ $? -ne 0 ]; then 
	 echo
	 echo "Configure for a 32 bit version failed. For more information look at:`pwd`/$MAKELOG"
  	 echo "Skipping libsdp 32 bit version."
  else
	  make install >> $MAKELOG 2>&1 &
	  make_pid=$!
	  if [ "$batch" == "no" ]; then
	     ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
	  fi
	  wait $make_pid >/dev/null 2>&1 
	  
	  if [ $? -ne 0 ]; then 
		 echo
		 echo "Failed to build 32 bit library. For more information look at:`pwd`/$MAKELOG"
		 exit 1
	  fi
  fi
  make clean  >> $MAKELOG 2>&1
 
  export CFLAGS=-m64
  export CXXFLAGS=-m64
  export FFLAGS=-m64
  export LDFLAGS="-m64 -Xcompiler -m64"

  echo "Making IBGD libsdp in ${tmpdir} (64 bit version ) ..."
  ./configure --prefix=${prefix} --libdir=${prefix}/lib64 >> $MAKELOG 2>&1
  make install >> $MAKELOG 2>&1 &
  make_pid=$!
  if [ "$batch" == "no" ]; then
     ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
  fi
  wait $make_pid >/dev/null 2>&1 
  
  if [ $? -ne 0 ]; then 
  	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
  	 exit 1
  fi
else
  echo "Making IBGD libsdp in ${tmpdir} ..."
  ./configure --prefix=${prefix} >> $MAKELOG 2>&1
  make install >> $MAKELOG 2>&1 &
  make_pid=$!
  if [ "$batch" == "no" ]; then
     ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
  fi
  wait $make_pid >/dev/null 2>&1 
  
  if [ $? -ne 0 ]; then 
  	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
  	 exit 1
  fi
fi

echo "Installation of IBGD libsdp (user) completed successfully"


##############################################################
###     cmlib
##############################################################


# Open the tar file into the tmp dir:
cd ${tmpdir}
ex tar -zxf ${installdir}/cmlib.tgz

# we rely on the fact we have opened the tar file so 
# have a local base dir:
if [ ! -d cmlib ]; then 
	 echo "Expected to find a sub-directory named 'cmlib' in current dir"
 	 echo "TAR file probably was not opened locally!"
	 exit
fi

ex cp -rp ${tmpdir}/cmlib ${prefix}/src

export MAKELOG=make-cmlib.log
export EXPECTED_MAKELOG_SIZE=400

cd ${tmpdir}/cmlib
/bin/rm -f $MAKELOG
echo "Making IBGD cmlib in ${tmpdir} ..."
make OPENIB_USER_DIR=$prefix KERNEL_SRC_DIR=$KSRC install > $MAKELOG 2>&1 &
make_pid=$!
if [ "$batch" == "no" ]; then
   ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
fi
wait $make_pid >/dev/null 2>&1 

if [ $? -ne 0 ]; then 
	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
	 exit 1
fi

echo "Installation of IBGD cmlib (user) completed successfully"


##############################################################
###     udapl and kdapltest
##############################################################

#if [ "$vapi_ver" == "3.2" ]; then 
# Open the tar file into the tmp dir:
cd ${tmpdir}
ex tar -zxf ${installdir}/dapl_new.tgz

# we rely on the fact we have opened the tar file so 
# have a local base dir:
if [ ! -d dapl_new ]; then 
	 echo "Expected to find a sub-directory named 'udapl' in current dir"
 	 echo "TAR file probably was not opened locally!"
	 exit
fi

ex cp -rp ${tmpdir}/dapl_new ${prefix}/src/

export MAKELOG=make-udapl.log
export EXPECTED_MAKELOG_SIZE=85000

cd ${tmpdir}/dapl_new
/bin/rm -f $MAKELOG
echo "Making IBGD udapl in ${tmpdir} ..."
make PREFIX=$prefix OPENIB_KERNEL_DIR=$KSRC/drivers/infiniband DAT_CONF_TARGET=$prefix/etc install > $MAKELOG 2>&1 &
make_pid=$!
if [ "$batch" == "no" ]; then
   ${installdir}/fprogbar.sh $MAKELOG $EXPECTED_MAKELOG_SIZE $make_pid
fi
wait $make_pid >/dev/null 2>&1 

if [ $? -ne 0 ]; then 
	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
	 exit 1
fi


if [ $SET_ENV -eq 1 ]; then 
  ex sed 's@/usr/local/ibgd@'$prefix'@g' ${prefix}/etc/dat.conf > ${prefix}/etc/dat.conf.new
   ex mv -f ${prefix}/etc/dat.conf.new /etc/dat.conf
   ex /bin/rm -f ${prefix}/etc/dat.conf 
   if ( /sbin/lspci -n | grep "15b3:6282" > /dev/null ); then #Found Arbel memfree
        perl -ni -e  "s@InfiniHost0@InfiniHost_III_Ex0@;print" /etc/dat.conf
   fi
   if ( /sbin/lspci -n | grep -E "15b3:5e8c|15b3:6274" > /dev/null ); then #Found Sinai
        perl -ni -e  "s@InfiniHost0@InfiniHost_III_Lx0@;print" /etc/dat.conf
   fi
fi
echo "Installation of IBGD uDAPL completed successfully"

##############################################################
###     scsidev
##############################################################

cd ${tmpdir}
ex tar -zxf ${installdir}/scsidev.tgz
mkdir -p ${prefix}/man
mkdir -p ${prefix}/man/man8

# we rely on the fact we have opened the tar file so 
# have a local base dir:
if [ ! -d scsidev ]; then 
	 echo "Expected to find a sub-directory named 'scsidev' in current dir"
 	 echo "TAR file probably was not opened locally!"
	 exit
fi

export MAKELOG=make-scsidev.log
export EXPECTED_MAKELOG_SIZE=85000

cd ${tmpdir}/scsidev
/bin/rm -f $MAKELOG
echo "Making scsidev in ${tmpdir} ..."
./configure --quiet --prefix=$prefix --exec-prefix=$prefix > /dev/null
make prefix=$prefix exec_prefix=$prefix install > $MAKELOG 2>&1 &
if [ $? -ne 0 ]; then 
	 echo "Make failed. For more information look at:`pwd`/$MAKELOG"
	 exit 1
fi

echo "Installation of scsidev completed successfully"

if [ -f ${installdir}/BUILD_ID ]; then
    ex cp ${installdir}/BUILD_ID ${prefix}
fi


if [ "${clean}" == "yes" ]; then
    echo "Cleaning up temporary build tree"
    rm -rf ${tmpdir}
fi

echo "Adding utility scripts to user installation to ${prefix}"
mkdir -p ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/create_devs ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/update_ipoib_intfs ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/DaplRegress.sh ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/srp_persistent_bind.sh ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/remove_srp_bind_persistent.sh  ${prefix}/utils
ex install -m 0755 ${tmpdir}/utils/rescan-scsi-bus.sh  ${prefix}/utils
ex install -m 0644 ${tmpdir}/utils/srp_persistent_bind.conf  ${prefix}/etc

#Run this part to update running environment
if [ $SET_ENV -eq 1 ]; then  

# Update srp configuration scripts
    ex perl -ni -e "s@/usr/local/ibgd@${prefix}@;print" ${prefix}/utils/srp_persistent_bind.sh
    ex perl -ni -e "s@/usr/local/ibgd@${prefix}@;print" ${prefix}/utils/remove_srp_bind_persistent.sh

#Determine if it is an Arbel or Tavor (or Arbel in Tavor mode) machine. This will
#determine if we should use thh or rhh. Ofcourse this is relevant only in 4.0
    if ( /sbin/lspci -n | grep "15b3:6282" > /dev/null ); then #Found Arbel in Arbel mode
         hh=mod_rhh
    elif ( /sbin/lspci -n | grep -E "15b3:5e8c|15b3:6274" > /dev/null ); then #Found Sinai
         hh=mod_rhh
    else 
          hh=mod_thh
    fi


    if [ "${KVERSION_TWO_DIGITS}" == "26" ]; then 
          echo "Updating /etc/modprobe.conf ..."
          /bin/rm -f /etc/modprobe-openib.conf
          if [ "$vapi_ver" == "3.2" ]; then 
cat >> /etc/modprobe-openib.conf << EOF
#
# InfiniBand module loading configuration
#
alias ib0 ib_ipoib
alias ib1 ib_ipoib

alias net-pf-26 ib_sdp
alias kdapl dat_registry
alias kdapltest kdapltest_module

options mod_thh thh_legacy_sqp=0

install mod_vapi /sbin/modprobe -i mod_vapi && ${prefix}/driver/infinihost/bin/open_hcas
install mod_vipkl /sbin/modprobe -i mod_vipkl && ${prefix}/utils/create_devs vipkl
install mosal /sbin/modprobe -i mosal && ${prefix}/utils/create_devs mosal
install ib_ipoib /sbin/modprobe -i ib_ipoib && ${prefix}/utils/update_ipoib_intfs && /sbin/modprobe ib_useraccess && /sbin/modprobe ib_ip2pr
install ib_ip2pr /sbin/modprobe -i ib_ip2pr && ${prefix}/utils/create_devs ib_ip2pr && /sbin/modprobe ib_dapl_srv
install ib_dapl_srv /sbin/modprobe -i ib_dapl_srv && ${prefix}/utils/create_devs ib_udapl && /sbin/modprobe ib_useraccess_cm
install ib_useraccess /sbin/modprobe -i ib_useraccess && ${prefix}/utils/create_devs ib_useraccess
install ib_useraccess_cm /sbin/modprobe -i ib_useraccess_cm && ${prefix}/utils/create_devs ib_useraccess_cm
install ib_sa_client /sbin/modprobe -i ib_sa_client && /sbin/modprobe ib_useraccess
install ib_srp /sbin/modprobe -i ib_srp && { ${prefix}/utils/srp_persistent_bind.sh & }
remove ib_srp ${prefix}/utils/remove_srp_bind_persistent.sh && /sbin/modprobe -r -q --ignore-remove ib_srp
install ib_mad /sbin/modprobe -i ib_mad && /sbin/modprobe ib_tavor
install dat_registry /sbin/modprobe -i dat_registry && /sbin/modprobe ib_kdapl 
install kdapltest_module /sbin/modprobe -i kdapltest_module && ${prefix}/utils/create_devs kdapltest_module
EOF
          else
		if [ "x$(uname -m)" == "xx86_64" ] && cat /proc/cpuinfo | grep 'AMD' > /dev/null ; then
			disable_msix=1
		else
			disable_msix=0
		fi
           

cat >> /etc/modprobe-openib.conf << EOF
#
# InfiniBand module loading configuration
#
alias ib0 ib_ipoib
alias ib1 ib_ipoib

alias net-pf-26 ib_sdp
alias kdapl dat_registry
alias kdapltest kdapltest_module
alias /dev/mosal mlxsys
alias /dev/vipkl mod_vip

options mod_thh disable_msix=${disable_msix}
options mod_rhh disable_msix=${disable_msix}

# mlxsys
install mlxsys /sbin/modprobe -q --ignore-install mlxsys && { rm -f /dev/mosal; mknod /dev/mosal c \`awk '(\$2=="mosal") {print \$1}' /proc/devices\` 33; }
remove mlxsys /sbin/modprobe -r -q --ignore-remove mlxsys && { /bin/rm -f /dev/mosal; }

# mod_vapi
install mod_vip /sbin/modprobe -q --ignore-install mod_vip && { rm -f /dev/vipkl; mknod /dev/vipkl c \`awk '(\$2=="mellanox_vipkl") {print \$1}' /proc/devices\` 1; } && /sbin/modprobe ${hh}
remove mod_vip /sbin/modprobe -r -q --ignore-remove mod_vip && { /bin/rm -f /dev/vipkl; }

# mod_thh/mod_rhh
install ${hh} /sbin/modprobe -q --ignore-install ${hh} && open_hcas
remove ${hh} close_hcas ; /sbin/modprobe -r -q --ignore-remove ${hh}

install ib_ipoib /sbin/modprobe -i ib_ipoib && ${prefix}/utils/update_ipoib_intfs && /sbin/modprobe ib_useraccess && /sbin/modprobe ib_ip2pr
install ib_ip2pr /sbin/modprobe -i ib_ip2pr && ${prefix}/utils/create_devs ib_ip2pr && /sbin/modprobe ib_dapl_srv
install ib_dapl_srv /sbin/modprobe -i ib_dapl_srv && ${prefix}/utils/create_devs ib_udapl && /sbin/modprobe ib_useraccess_cm
install ib_useraccess /sbin/modprobe -i ib_useraccess && ${prefix}/utils/create_devs ib_useraccess
install ib_useraccess_cm /sbin/modprobe -i ib_useraccess_cm && ${prefix}/utils/create_devs ib_useraccess_cm
install ib_sa_client /sbin/modprobe -i ib_sa_client && /sbin/modprobe ib_useraccess
install ib_srp /sbin/modprobe -i ib_srp && { ${prefix}/utils/srp_persistent_bind.sh & }
remove ib_srp ${prefix}/utils/remove_srp_bind_persistent.sh && /sbin/modprobe -r -q --ignore-remove ib_srp
install ib_mad /sbin/modprobe -i ib_mad && /sbin/modprobe ib_tavor
install dat_registry /sbin/modprobe -i dat_registry && /sbin/modprobe ib_kdapl 
install kdapltest_module /sbin/modprobe -i kdapltest_module && ${prefix}/utils/create_devs kdapltest_module
remove ib_tavor /sbin/modprobe -r -q --ignore-remove ib_tavor && /sbin/modprobe -r ${hh}
EOF
          fi
          perl -i.orig -ne 'print unless (m@include /etc/modprobe-openib.conf@)' /etc/modprobe.conf
          echo "include /etc/modprobe-openib.conf" >> /etc/modprobe.conf
    else 
          echo "Updating /etc/modules.conf ..."
          /bin/rm -f /etc/modules-openib.conf
          if [ "$vapi_ver" == "3.2" ]; then 
cat >> /etc/modules-openib.conf << EOF
#
# InfiniBand module loading configuration
#
alias ib0  ib_ipoib 
alias ib1  ib_ipoib

alias net-pf-26 ib_sdp 
options mod_thh thh_legacy_sqp=0
alias kdapl dat_registry
alias kdapltest kdapltest_module

post-install mod_vapi  ${prefix}/driver/infinihost/bin/open_hcas 
post-install mosal ${prefix}/utils/create_devs mosal
post-install mod_vipkl ${prefix}/utils/create_devs vipkl 
post-install ib_useraccess ${prefix}/utils/create_devs ib_useraccess 
post-install ib_ipoib ${prefix}/utils/update_ipoib_intfs 
add above ib_ipoib ib_useraccess
add above ib_ipoib ib_ip2pr 
post-install ib_ip2pr ${prefix}/utils/create_devs ib_ip2pr 
add above ib_ip2pr ib_dapl_srv
post-install ib_dapl_srv ${prefix}/utils/create_devs ib_udapl 
add above ib_dapl_srv ib_useraccess_cm 
post-install ib_useraccess_cm ${prefix}/utils/create_devs ib_useraccess_cm 
post-install ib_srp { ${prefix}/utils/srp_persistent_bind.sh & }
pre-remove ib_srp ${prefix}/utils/remove_srp_bind_persistent.sh 
add above ib_sa_client ib_useraccess 
add below ib_ipoib ib_tavor
post-install dat_registry /sbin/modprobe ib_kdapl 
post-install kdapltest_module ${prefix}/utils/create_devs kdapltest_module
EOF
          else
cat >> /etc/modules-openib.conf << EOF
#
# InfiniBand module loading configuration
#
alias ib0  ib_ipoib 
alias ib1  ib_ipoib

alias net-pf-26 ib_sdp

alias /dev/mosal mlxsys
alias /dev/vipkl mod_vapi
alias kdapl dat_registry
alias kdapltest kdapltest_module

post-install mlxsys { rm -f /dev/mosal; mknod /dev/mosal c \`awk '(\$2=="mosal") {print \$1}' /proc/devices\` 33 ; }
post-remove mlxsys /bin/rm -f /dev/mosal

post-install mod_vip { rm -f /dev/vipkl; mknod /dev/vipkl c \`awk '(\$2=="mellanox_vipkl") {print \$1}' /proc/devices\` 1 ; } && /sbin/modprobe ${hh}
post-remove mod_vip /bin/rm -f /dev/vipkl

post-install ${hh} open_hcas
pre-remove ${hh} close_hcas

post-install ib_useraccess ${prefix}/utils/create_devs ib_useraccess 
post-install ib_ipoib ${prefix}/utils/update_ipoib_intfs 
add above ib_ipoib ib_useraccess
add above ib_ipoib ib_ip2pr 
post-install ib_ip2pr ${prefix}/utils/create_devs ib_ip2pr 
add above ib_ip2pr ib_dapl_srv
post-install ib_dapl_srv ${prefix}/utils/create_devs ib_udapl 
add above ib_dapl_srv ib_useraccess_cm 
post-install ib_useraccess_cm ${prefix}/utils/create_devs ib_useraccess_cm 
add above ib_sa_client ib_useraccess 
add below ib_ipoib ib_tavor
post-remove ib_tavor /sbin/modprobe -r ${hh} 
post-install ib_srp { ${prefix}/utils/srp_persistent_bind.sh & }
pre-remove ib_srp ${prefix}/utils/remove_srp_bind_persistent.sh 
post-install dat_registry /sbin/modprobe ib_kdapl 
post-install kdapltest_module ${prefix}/utils/create_devs kdapltest_module
EOF
          fi       
          perl -i.orig -ne 'print unless (m@include /etc/modules-openib.conf@)' /etc/modules.conf
          echo "include /etc/modules-openib.conf" >> /etc/modules.conf
    fi
    
   if [ -d  ${prefix}/driver/infinihost/lib ]; then
    	perl -i.orig -ne "print unless (m@${prefix}/driver/infinihost/lib@)" /etc/ld.so.conf
    	echo "${prefix}/driver/infinihost/lib" >> /etc/ld.so.conf
   fi

   if [ -d ${prefix}/driver/infinihost/lib64 ]; then
    	perl -i.orig -ne "print unless (m@${prefix}/driver/infinihost/lib64@)" /etc/ld.so.conf
    	echo "${prefix}/driver/infinihost/lib64" >> /etc/ld.so.conf
   fi

    perl -i.orig -ne "print unless (m@${prefix}/lib@)" /etc/ld.so.conf 
    echo "${prefix}/lib" >> /etc/ld.so.conf

	if [ -d ${prefix}/lib64 ]; then
	perl -i.orig -ne "print unless (m@${prefix}/lib64@)" /etc/ld.so.conf
    echo "${prefix}/lib64" >> /etc/ld.so.conf
	fi
    /sbin/ldconfig

    echo "Running depmod ..."
    if [ "${KVERSION_TWO_DIGITS}" == "24" ]; then
             /sbin/depmod -r -ae -F /boot/System.map-${KVERSION} ${KVERSION}
    else
             /sbin/depmod -r -ae ${KVERSION}
    fi
  
    if [ $? -ne 0 ]; then
         echo "Depmod failed."
         exit 1
    fi

 ##Take care of libsdp.conf
 /bin/rm -f /etc/libsdp.conf
fi

echo "user-install done in ${prefix}"

exit 0

