#!/bin/bash 

# This software is available to you under a choice of one of two
# licenses.  You may choose to be licensed under the terms of the GNU
# General Public License (GPL) Version 2, available at
# <http://www.fsf.org/copyleft/gpl.html>, or the OpenIB.org BSD
# license, available in the LICENSE.TXT file accompanying this
# software.  These details are also available at
# <http://openib.org/license.html>.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# Copyright (c) 2004 Mellanox Technologies Ltd.  All rights reserved.
#
# Description: RPM build script
#

build_root="/var/tmp/IBGD"
OSMHOME=/usr/local/ibgd/apps/osm
VENDOR=ts

k_ver=`uname -r`

if [ -d "/lib/modules/${k_ver}/source/" ]; then
    MTHOME=/lib/modules/${k_ver}/source/drivers/infiniband/hw/mellanox-hca
    TSHOME=/lib/modules/${k_ver}/source/drivers/infiniband/include
else
    MTHOME=/lib/modules/${k_ver}/build/drivers/infiniband/hw/mellanox-hca
    TSHOME=/lib/modules/${k_ver}/build/drivers/infiniband/include
fi

usage()
{
cat << EOF

    `basename $0` [ -b <BUILD_ROOT> ] [ -d <install-dir> ] [ -m MTHOME ] [ -t TSHOME ] [ -b build_root ] [ -v VENDOR ]
			
		The default install-dir is $OSMHOME
		The default MTHOME 	is $MTHOME
		The default TSHOME 	is $TSHOME
		The default BUILD_ROOT  is $build_root
		VENDOR must be "mtl" or "ts" ( Default - "ts" )

EOF
}

while [ $# -gt 0 ]
do
    case $1 in
            -d)
                shift
                OSMHOME=$1
            ;;
            -m)
                shift
                MTHOME=$1
            ;;
            -t)
                shift
                TSHOME=$1
            ;;
            -v)
                shift
                VENDOR=$1
            ;;
	    -b)
		shift
		build_root=$1
	    ;;
            *)
                usage
                exit 1
            ;;
    esac            
    shift
done

BUILD_ENV="env build_root=$build_root OSMHOME=$OSMHOME MTHOME=$MTHOME TSHOME=$TSHOME VENDOR=$VENDOR"

cd ${0%*/*}

TMPFILE=/tmp/$$.tmp
SOURCE_DIR=`pwd`
KERNEL=`uname -r | sed -e "s/\-/\_/g"`
OSM_DIR=${PWD##*/}
NAME=`echo ${PWD##*/} | cut -d \- -f 1`
VERSION=`echo ${PWD##*/} | cut -d \- -f 2- | tr -s '-' '_'`
RELVER=`echo ${PWD##*/} | cut -d \- -f 2-`

# Check kernel sources existence
if ! test -d /lib/modules/`uname -r`/build; then
	echo In order to build RPM kernel sources need to be installed
	exit 1
fi

build_arch=`rpm --showrc | grep -w "build arch" | cut -d : -f 2 | tr -d " "`
spec="opensm.spec"

if [ -d /usr/src/redhat ]; then
	RPM_DIR=/usr/src/redhat
elif [ -d /usr/src/packages ]; then
	RPM_DIR=/usr/src/packages
else
	echo Build rpm on this system is not supported...
	exit 1
fi

if [ -f $RPM_DIR/SPECS/$spec ]; then
	rm -f $RPM_DIR/SPECS/$spec 
fi

# Update Package name, version and release in the spec file
sed -e "s/XXXXXX/$VERSION/g" -e "s/YYYYYY/$NAME/g" -e "s/ZZZZZZ/$RELVER/g" $spec > $RPM_DIR/SPECS/$spec

cd ..
rm -f /tmp/${NAME}-${RELVER}.tgz
tar czvf /tmp/${NAME}-${RELVER}.tgz $OSM_DIR > /dev/null 2>&1
mv -f /tmp/${NAME}-${RELVER}.tgz $RPM_DIR/SOURCES/

if [ -f /etc/SuSE-release ]; then
   if [ `grep VERSION /etc/SuSE-release | cut -d = -f 2 | cut -d . -f 1 | tr -d [:space:]` -ge 9 ]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$spec # > /dev/null 2>&1
   else	
	$BUILD_ENV rpm -bb $RPM_DIR/SPECS/$spec # > /dev/null 2>&1
   fi
elif [[ -f /etc/redhat-release || -f /etc/rocks-release ]]; then
	$BUILD_ENV rpmbuild -bb $RPM_DIR/SPECS/$spec # > /dev/null 2>&1
else
        echo Build rpm on this system is not supported...
        exit 1
fi

if [ $? != 0 ]; then
    echo RPM building failed...
    exit 1
fi 

rm -f $RPM_DIR/SOURCES/$OSM_DIR.tgz
rm -f $RPM_DIR/SPECS/$spec

if [ ! -f $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm ] ; then
	echo RPM building failed...
	exit 1
else
	echo RPM: $RPM_DIR/RPMS/$build_arch/${NAME}-${VERSION}-${KERNEL}.${build_arch}.rpm 
fi

exit 0

